# LinEAK - Linux Support for Easy Access and Internet Keyboards
#  Copyright (C) 2001,2002 Mark Smulders <Mark@PIRnet.nl>
# 		and Sheldon Lee-Wen <leewsb@hotMail.com>
#
# keyboard definition file:
#   this file defines the extra keys of the keyboard types,
#   and the corresponding keycode.
#
# if your keyboard is not in here, please send me an e-Mail so
# I can add Support for it.
#
# WARNING: this definition file is NOT compatible with
#          lineakd 0.1 and 0.2
#          lineakconfig 0.1


#### A4Tech Keyboards ####

[A4-KBS8]
  brandname = "A4Tech"
  modelname = "KBS-8"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Search           = 229
    Favorites        = 230
    WWW              = 178
    Mail             = 236
    AudioMute        = 160    
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    AudioMedia       = 237
    MyComputer       = 235
    Calculator       = 161
    Sleep            = 223
  [END KEYS]
[END A4-KBS8]

[A4-RFKB23]
  brandname = "A4Tech"
  modelname = "RFKB-23"
  [KEYS]
    Calculator      = 161
    Down            = 233
    Exit            = 232
    Folder          = 230
    Forward         = 153
    WWW             = 178
    Less            = 174
    Magnifier       = 229
    Mail            = 236
    More            = 176
    AudioMute       = 160
    AudioPlay|Pause = 162
    Reload          = 231
    Rewind          = 144
    Shell           = 235
    Sleep           = 223
    Sound           = 237
    AudioStop       = 164
    Up              = 234
  [END KEYS]
[END A4-RFKB23]

[A4-RFKB25]
  brandname = "A4Tech"
  modelname = "RFKB-25 (KBS-2548RP & KBS-2548RPC)"
  [KEYS]
    Back             = 234
    Forward          = 233
    Search           = 229
    Favorites        = 230
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrevious    = 144
    AudioNext        = 153
    AudioMedia       = 237
    Eject            = 231
    Sleep            = 223
    PowerOff         = 232
    Community        = 235
    Documents        = 226
    Go               = 161
## EXPERIMENTAL - If You Fix The following Please E-mail
## 'Have no luck to put scroll well to work
## 'keyboard lock-up at the keycode 139
#   ScrollUp         = 172
#   ScrollDown       = 139
  [END KEYS]
[END A4-RFKB25]

[A4-KBS21]
  brandname = "A4Tech"
  modelname = "Wireless Desktop KBS-21533RP & Office/Multimedia Keyboard"
  [KEYS]
    Back        = 234
    WebForward  = 233
    WebStop     = 232
    WebRefresh  = 231
    Home        = 178
    Search      = 229
    Stop        = 164
    Play|Pause  = 162
    Next        = 153
    Previous    = 144
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Favorites   = 230
    Mail        = 236
    MyComputer  = 235
  [END KEYS]
[END A4-KBS21]

#### END A4Tech Keyboards ####


#### Acer Keyboards ####

[ACE-6512UV]
  brandname = "Acer"
  modelname = "6512-UV"
  [KEYS]
    WWW              = 130
    Mail             = 236
    AudioMute        = 160
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    Sleep            = 223
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END ACE-6512UV]

[ACEAKV12]
  brandname = "Acer"
  modelname = "AirKey V (12 keys)"
  [KEYS]
    Previous    = 152
    Play|Pause  = 149
    Stop|Eject  = 177
    Next        = 147
    VolumeUp    = 173
    VolumeDown  = 166
    Mute        = 153
    Internet    = 164
    Mail        = 150
    Terminal    = 175
    Sleep       = 227
    Power       = 222
  [END KEYS]
[END ACEAKV12]

[ACE-TM290]
  brandname = "Acer Laptop/notebook"
  modelname = "Travelmate 290LCi"
  [KEYS]
    AudioMute        = 160
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    WWW              = 236
    Mail             = 178
    Sleep            = 223
  [ENDKEYS]
[END ACE-TM290]

#### END Acer Keyboards ####


#### Adesso Keyboards ####

[ADEL-9805]
  brandname = "Adesso"
  modelname = "EL-9805"
  [KEYS]
    WWW              = 178
    Mail             = 236
    Back             = 234
    Forward          = 233
    Search           = 229
    Refresh          = 231
    Favorites        = 230
    Stop             = 232
    AudioMedia       = 237
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
    AudioStop        = 164
    AudioPrev        = 144
    AudioPlay|Pause  = 162
    AudioNext        = 153
    PowerOff         = 235
    Sleep            = 223
  [END KEYS]
[END ADEL-9805]

#### END Adesso Keyboards ####


### Apple Keyboards ###

[APK7]
  brandname = "Apple"
  modelname = "Pro Keyboard (7 keys)"
  [KEYS]
    VolumeDown  = 165
    VolumeUp    = 158
    Mute        = 166
    Eject       = 116
    F13         = 93
    F14         = 123
    F15         = 127
  [END KEYS]
[END APK7]

[APK9]
  brandname = "Apple"
  modelname = "Pro Keyboard (9 keys)"
  [KEYS]
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
    MediaEject       = 204
    F13              = 182
    F14              = 183
    F15              = 184
    Sleep            = 93   #F16 key
    Shell            = 157  #'=' key
  [END KEYS]
[END APK9]

#### END Apple Keyboards ####


#### BenQ Keyboards ####

[BEN-A122]
  brandname = "BenQ"
  modelname = "A122 (6 keys)"
  [KEYS]
    Sleep            = 223
    Back             = 234
    Forward          = 233
    Home             = 178
    Mail             = 236
    Favorites        = 230
  [END KEYS]
[END BEN-A122]

[BEN-AM805]
  brandname = "BenQ"
  modelname = "AM805"
  [KEYS]
    Mail             = 236
    AudioNext        = 153
    AudioMute        = 160
    AudioPlay|Pause  = 162
    Power            = 223
    AudioPrev        = 144
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END BEN-AM805]

#### END BenQ Keyboards ####

#### BTC keyboards ####

[BTC5107] # Alexander Ciobanu
  brandname = "BTC"
  modelname = "5107"
  [KEYS]
    PowerDown   = 222
    Sleep       = 223
    Wake        = 227
  [END KEYS]
[END BTC5107]

[BTC5113RF]
  brandname = "BTC"
  modelname = "5113RF MultiMedia"
  [KEYS]
    Internet    = 176
    WebBack     = 166
    Favorites   = 160
    Search      = 178
    VolumeDown  = 165
    VolumeUp    = 158
    Mute        = 146
    Previous    = 162
    Play        = 153
    Stop        = 144
    Next        = 164
    Eject       = 161
    Power       = 222
    Sleep       = 223
    Wake        = 227
  [END KEYS]
[END BTC5113RF]

[BTC5126T]
  brandname = "BTC"
  modelname = "5126T"
  [KEYS]
    Internet    = 176
    Sleep       = 223
    Mail        = 171
  [END KEYS]
[END BTC5126T]

[USRmB9]
  brandname = "BTC"
  modelname = "9000A Alternate"
  [KEYS]
    Favorites   = 160
    Bookmark    = 166
    Eject       = 161
    Search      = 178
    Help        = 174
    Home        = 176
    Mute        = 146
    Next        = 164
    Play|Pause  = 153
    Power       = 222
    Previous    = 162
    Sleep       = 223
    Stop        = 144
    VolumeDown  = 165
    VolumeUp    = 158
    Wake        = 227
  [END KEYS]
[END 9000A]

[BTC9000A]
  brandname = "BTC"
  modelname = "9000A"
  [KEYS]
    Play|Pause  = 153
    Previous    = 162
    Next        = 164
    Stop        = 144
    Eject       = 161
    VolumeUp    = 158
    VolumeDown  = 165
    Mute        = 146
    Internet    = 176
    Home        = 166
    Search      = 178
    Favorites   = 160
    Help        = 174
    Wake        = 227
    Sleep       = 223
    Power       = 222
  [END KEYS]
[END BTC9000A]

[BTC9000]
  brandname = "BTC"
  modelname = "9000"
  [KEYS]
    Documents   = 174
    Favorites   = 160
    Home        = 166
    Internet    = 176
    Search      = 178
    Play|Pause  = 153
    Previous    = 162
    Next        = 164
    Stop        = 144
    Eject       = 161
    Sleep       = 223
    VolumeDown  = 165
    VolumeUp    = 158
    Mute        = 146
    Sleep       = 223
    Power       = 222
    Wake        = 227
  [END KEYS]
[END BTC9000]

[BTC9001A]
  brandname = "BTC"
  modelname = "9001A"
  [KEYS]
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    AudioNext        = 153
    AudioStop        = 164
    Eject            = 116
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    AudioMute        = 160
    WWW              = 178
    Favorites        = 230
    Search           = 229
    Homepage         = 133
    Help             = 115
    Wake             = 227
    Sleep            = 223
    PowerOff         = 222
  [END KEYS]
[END BTC9001A]

[BTC9110] # Contributed by Renze de Ruiter <renze@ihug.co.nz>
  brandname = "BTC"
  modelname = "9110"
  [KEYS]
    Function3   = 173
    Function4   = 167
    FunctionSelect = 163
    Suspend     = 223
  [END KEYS]
[END 9110]

#### END BTC Keyboards ####


#### Cherry Keyboards ####

[CBLCB]
  brandname = "Cherry"
  modelname = "Blue Line CyBo@rd"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    WebReload   = 121
    Search      = 229
    My Computer = 230
    Home        = 130
    Mail        = 236
    Terminal    = 111
    Calculator  = 161
    VolumeUp    = 158
    Mute        = 166
    VolumeDown  = 165
    Go          = 129
    Previous    = 164
    Next        = 162
    Play        = 159
    Stop        = 151
    Sleep       = 227
  [END KEYS]
[END CBLCB]

[CBLCBa]
  brandname = "Cherry"
  modelname = "Blue Line CyBo@rd (alternate option a)"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    WebReload   = 231
    Search      = 229
    My Computer = 230
    Home        = 178
    Mail        = 236
    Terminal    = 235
    Calculator  = 161
    VolumeUp    = 176
    Mute        = 160
    VolumeDown  = 174
    Go          = 237
    Previous    = 144
    Next        = 153
    Play        = 162
    Stop        = 164
    Sleep       = 223
  [END KEYS]
[END CBLCBa]

[CBLCBb]
  brandname = "Cherry"
  modelname = "Blue Line Cyboard (alternate option b)"
  [KEYS]
    Back        = 234
    Calculator  = 161
    Cancel      = 232
    Computer    = 235
    Email       = 236
    Folder      = 230
    Forward     = 233
    Home        = 178
    Media       = 237
    Mute        = 160
    Play        = 162
    Refresh     = 231
    Search      = 229
    Sleep       = 223
    Stop        = 164
    Previous    = 144
    Next        = 153
    VolumeUp    = 176
    VoumeDown   = 174
  [END KEYS]
[END CBLCBb]

[CC-CYREG]
  brandname = "Cherry"
  modelname = "Cybord (Regular?)"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Calculator       = 161
    Mail             = 236
    FileManager      = 230
    WWW              = 130
    AudioMute        = 160
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    Search           = 122
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END CC-CYREG]

[CCYMAST]
  brandname = "Cherry"
  modelname = "Cherry Cymotion Master"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    WebReload   = 231
    Search      = 229
    My Computer = 230
    Home        = 178
    Mail        = 236
    Terminal    = 235
    Calculator  = 161
    VolumeUp    = 176
    Mute        = 160
    VolumeDown  = 174
    Media       = 237
    Previous    = 144
    Next        = 153
    Play        = 162
    Stop        = 164
    Sleep       = 223
    Document1   = 241
    Document2   = 172
    Document3   = 242
    Eject       = 240
    MediaUp     = 139
    MediaDown   = 146
    Cut         = 151
    Copy        = 138
    Paste       = 152
    MediaRight  = 135
    MediaLeft   = 136
  [END KEYS]
[END CCYMAST]

[CCYMAST9]
  brandname = "Cherry"
  modelname = "CyMotion Master Plus 9"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Search           = 229
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    AudioNext        = 153
    AudioMedia       = 237
    MyComputer       = 235
    Calculator       = 161
    An               = 227
    NewFolder        = 230
[END KEYS]
[END CYMAST9]

[CYTLC]
  brandname = "Cherry"
  modelname = "Trend Line CyBoard"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Reload           = 231
    Search           = 122
    MyComputer       = 230
    WWW              = 130
    Mail             = 236
    Terminal         = 111
    Calculator       = 161
    AudioRaiseVolume = 176
    AudioMute        = 160
    AudioLowerVolume = 174
    Go               = 129
    AudioPrev        = 144
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioStop        = 164
    Sleep            = 227
  [END KEYS]
[END CYTLC]

#### END Cherry Keyboards ####


#### Chic Keyboards ####

[Chic-WL]
  brandname = "Chic"
  modelname = "Wireless Keyboard"
  [KEYS]
    Back             = 234
    Bookmark         = 230
    Close            = 232
    Forward          = 233
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioNext        = 153
    AudioPlay|Pause  = 162
    PowerOff         = 222
    AudioPrev        = 144
    Refresh          = 231
    Search           = 229
    AudioStop        = 164
    Suspend          = 223
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END Chic-WL]

#### END Chic Keyboards ####


#### Chicony Keyboards ####

[CY0108]
  brandname = "Chicony"
  modelname = "Chicony KB-R0108 & KU-0108"
  [KEYS]
    Back             = 234
    Forward          = 233
    Search           = 122
    Favorites        = 230
    WWW              = 130
    Mail             = 236
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    Calculator       = 161
    Sleep            = 223
    Copy             = 248
    Cut              = 188
  [END KEYS]
[END CY0108]

[CY0173]
  brandname = "Chicony"
  modelname = "Chicony KB-0173 (5 keys)"
  [KEYS]
    VolumeDown  = 174
    VolumeUp    = 176
    Sleep       = 223
    Internet    = 178
    Mail        = 236
  [END KEYS]
[END CY0173]

[CY9810]
  brandname = "Chicony"
  modelname = "Chicony KB-9810"
  [KEYS]
    Power       = 222
    Wake        = 227
    Sleep       = 223
  [END KEYS]
[END CY9810]

[CY9885]
  brandname = "Chicony"
  modelname = "Chicony KB-9885 (17 keys)"
  [KEYS]
    VolumeDown  = 153
    Mute        = 146
    VolumeUp    = 163
    Previous    = 162
    Stop        = 164
    Play        = 161
    Next        = 160
    Power       = 222
    Sleep       = 223
    Wake        = 227
    Internet    = 178
    Mail        = 151
    UserDefined1 = 176
    UserDefined2 = 166
    UserDefined3 = 174
    WebBack     = 165
    WebForward  = 158
  [END KEYS]
[END CY9885]

#### END Chicony Keyboards ####


#### Clevo Keyboards ####

[CL-D470V]
  brandname = "Clevo laptop"
  modelname = "D470V"
  [KEYS]
    Launch0          = 129
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
[END KEYS]
[END CL-D470V]

#### END Clevo Keyboards ####


#### CodeGen Keyboards ####

[CG-KB2625]
  brandname = "Codegen"
  modelname = "KB-2625 (29 keys)"
  [KEYS]
    Logoff           = 150
    Calculator       = 161
    MyComputer       = 135
    Sleep            = 223
    Favorites        = 230
    Search           = 229
    Refresh          = 231
    Forward          = 233
    Back             = 234
    Mail             = 236
    Homepage         = 178
    AudioNext        = 153
    AudioPrev        = 144 
    AudioStop        = 164
    AudioPlay|Pause  = 162
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
    Calendar         = 149
    Spreadsheet      = 148
    Wordprocessor    = 147
    PowerOff         = 222
    MediaUp          = 159
    MediaDown        = 145
    Close            = 116
    Launch0          = 137
    Cut              = 151
    Paste            = 138
    Copy             = 152
  [END KEYS]
[END CG-KB2625]

#### END CodeGen Keyboards ####


#### Compaq keyboards ####

[CEA4]
  brandname = "Compaq"
  modelname = "Compaq (eg. Armada) Laptop Keyboard (4 keys)"
  [KEYS]
    Internet    = 163
    Home        = 159
    Search      = 154
    Mail        = 158
  [END KEYS]
[END CEA4]

[CIKP800]
  brandname = "Compaq"
  modelname = "Compaq (eg. Persario) Laptop Internet Keyboard"
  [KEYS]
    Play        = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    UserDefined1 = 159
    UserDefined2 = 152
    Media       = 245
    Internet    = 163
    Q           = 148
    Shop        = 178
    Mail        = 158
    Mute        = 160
    Sleep       = 223
  [END KEYS]
[END CIKP800]

[CEAK8]
  brandname = "Compaq"
  modelname = "Easy Access Keyboard (8 keys)"
  [KEYS]
    Internet    = 163
    Home        = 159
    Search      = 154
    Mail        = 158
    Communities = 147
    Market      = 148
    Meeting     = 149
    News        = 155
  [END KEYS]
[END CEAK8]

[CP-EVON610C]
  brandname = "Compaq"
  modelname = "Evo N610C Notebook"
  [KEYS]
    Information      = 163
    WWW              = 159
    Mail             = 158
    Search           = 154
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
  [END KEYS]
[END CP-EVON610C] 

[CP-EVON620C]
  brandname = "Compaq"
  modelname = "EVO N620c Internet Keyboard"
  [KEYS]
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    AudioNext        = 153
    AudioStop        = 164
    Search           = 154
    Custom1          = 159
    Custom2          = 152
    AudioMedia       = 245
    WWW              = 163
    Q                = 148
    Shop             = 178
    Mail             = 158
    AudioMute        = 160
    Sleep            = 223
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
  [END KEYS]
[END CP-EVON620C]

[CIK13]
  brandname = "Compaq"
  modelname = "Internet Keyboard (13 keys)"
  [KEYS]
    Play        = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
    Sleep       = 223
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Go          = 159
    Internet    = 163
    Search      = 161
    Mail        = 158
    Shop        = 178
  [END KEYS]
[END CIK13]

[CIK18b]
  brandname = "Compaq"
  modelname = "Internet Keyboard (18 keys, blue)"
  [KEYS]
    Play        = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    Eject       = 152
    Mail        = 158
    Communities = 166
    VendorHome  = 165
    Internet    = 163
    Search      = 161
    Lightbulb   = 146
    Shop        = 178
    Print       = 232
    Go          = 159
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
    Sleep       = 223
  [END KEYS]
[END CIK18b]

[CIK18g]
  brandname = "Compaq"
  modelname = "Internet Keyboard (18 keys, grey)"
  [KEYS]
    Play        = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    Eject       = 152
    Mail        = 158
    Communities = 166
    VendorHome  = 165
    Internet    = 163
    Search      = 161
    Lightbulb   = 146
    Shop        = 178
    Print       = 232
    Go          = 159
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
    Sleep       = 223
  [END KEYS]
[END CIK18g]

[CiP]
  brandname = "Compaq"
  modelname = "iPaq Keyboard (7 keys)"
  [KEYS]
    Mail        = 236
    Back|Next   = 233
    Q           = 234
    Standby     = 130
    Search      = 229
    Travel      = 230
    Shop        = 121
  [END KEYS]
[END CiP]

[CPR3000Z]
  brandname = "Compaq"
  modelname = "Presario R3000Z"
  [KEYS]
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    WWW              = 178
    Sleep            = 223
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
  [END KEYS]
[END CPR3000Z]

[CP90x]
  brandname = "Compaq"
  modelname = "Presario 90x"
  [KEYS]
    Internet    = 163
    Mail        = 158
    Search      = 154
    Media       = 239
    VolumeDown  = 174
    VolumeUp    = 176
    Play        = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
  [END KEYS]
[END CP90x]

[CP-R3000Z]
  brandname = "Compaq"
  modelname = "Presario R3000Z"
  [KEYS]
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    WWW              = 178
    Sleep            = 223
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
  [END KEYS]
[END CP-R3000Z]

#### END Compaq Keyboards ####


#### Creative Keyboards ####

[CR-WCPAOD]
  brandname = "Creative"
  modelname = "Desktop Wireless WCPA0D"
  [KEYS]
    Back             = 233
    Mail             = 161
    Favorites        = 153
    Forward          = 232
    AudioMute        = 176
    AudioNext        = 144
    AudioPlay|Pause  = 160
    AudioPrev        = 164
    Refresh          = 230
    AudioStop        = 162
    Stop             = 231
    Search           = 130
    Suspend          = 223
    AudioLowerVolume = 129
    AudioRaiseVolume = 174
    WWW              = 234
  [END KEYS]
[END CR-WCPAOD]

#### END Creative Keyboards ####


#### Dell Keyboards ####
#  NOTE:  The Dell USB multiMedia keyboard patch is used to translate the
#         following keys below 256:
#
#           messenger  256 -> 240
#           webcam     257 -> 241
#           iTouch     258 -> 242
#           Shopping   259 -> 243
#
#         The Dell USB multiMedia keyboard patch can be found at
#         http://Internet.ece.utexas.edu/~jlang/linux-keyboard/
#
########################

[DELL-9100]
 brandname = "Dell"
 modelname = "Dell Inspiron 9100"
 [KEYS]
   Play        = 162
   Previous    = 144
   Next        = 153
   Stop        = 164
   VolumeUp    = 176
   VolumeDown  = 174
   Mute        = 160
 [END KEYS]
[END DELL-9100]

[DELL-D600]
  brandname = "Dell"
  modelname = "D600 (User Defined)"
  [KEYS]
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
  [END KEYS]
[END DELL-D600]

[DRT7D00] # By Oscar Urra Cuairán
  brandname = "Dell"
  modelname = "RT7D00"
  [KEYS]
    Home        = 166
    Mail        = 146
    Search      = 158
    Sleep       = 223
  [END KEYS]
[END DRT7D00]

[DI8K]
  brandname = "Dell"
  modelname = "Dell Inspiron 8xxx"
  [KEYS]
    Play        = 129
    Previous    = 131
    Next        = 132
    Stop        = 130
    VolumeUp    = 176
    VolumeDown  = 174
    Mute        = 160
  [END KEYS]
[END DI8K]

[DELL-I8600]
  brandname = "Dell"
  modelname = "Dell Inspiron 8600"
  [KEYS]
    AudioPrev        = 144
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioNext        = 153
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    AudioMute        = 160
  [END KEYS]
[END DELL-I8600]

[DELL-SK-8125] # By Rich Boakes
  brandname = "Dell"
  modelname = "SK-8125"
  [KEYS]
    Back        = 234
    Fwd         = 233
    Stop        = 232
    Reload      = 231
    Home        = 130
    VolumeDown  = 97
    VolumeUp    = 176
    Mute        = 174
  [END KEYS]
[END DELL-SK-8125]


[DELL-WL] # Craig Robinson
  brandname = "Dell"
  modelname = "Wireless Keyboard"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 121
    WWW              = 130
    Mail             = 236
    AudioMute        = 166
    AudioLowerVolume = 165
    AudioRaiseVolume = 158
    AudioPlay|Pause  = 159
    AudioStop        = 151
    AudioPrev        = 164
    AudioNext        = 162
    AudioMedia       = 129
    MyComputer       = 111
    Calculator       = 161
  [END KEYS]
[END DELL-WL]

[DELL-LT-D800]
   brandname = "Dell"
   modelname = "Latitude D800"
   [KEYS]
     Mute = 160
     VolumeUp = 176
     VolumeDown = 174
   [END KEYS]
[END DELL-LT-D800]


#### END Dell Keyboards ####


#### Dexxa Keyboards ####

[DEXXIK]
  brandname = "Dexxa"
  modelname = "Internet Keyboard (23 keys, model Y-SH16)"
  [KEYS]
    Go          = 158
    Undo        = 173
    Redo        = 177
    Calculator  = 161
    Shopping    = 152
    Refresh     = 231
    WebStop     = 232
    Favorites   = 230
    Home        = 178
    Search      = 229
    Mail        = 236
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
    Previous    = 144
    Stop        = 164
    Record      = 147
    Play        = 162
    Next        = 153
    Eject       = 148
    Back        = 234
    Forward     = 233
    Sleep       = 223
  [END KEYS]
[END DEXXIK]

[DEXXWD]
  brandname = "Dexxa"
  modelname = "Wireless Desktop Keyboard (9 keys)"
  [KEYS]
    WebReload   = 231
    Favorites   = 230
    Search      = 229
    Mail        = 236
    Internet    = 178
    Play        = 162
    VolumeUp    = 176
    VolumeDown  = 174
    Mute        = 160
  [END KEYS]
[END DEXXWD]

#### END Dexxa Keybaords ####


#### Diamond Keyboards ####

[DIA9801]
  brandname = "Diamond"
  modelname = "Diamond 9801 / 9802 series (22 keys)"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    Favorites   = 230
    Search      = 229
    WebReload   = 231
    Home        = 178
    Mail        = 236
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
    Go          = 237
    Stop        = 164
    Play        = 162
    Next        = 153
    Previous    = 144
    Calculator  = 161
    My Computer = 235
    Power       = 222
    Sleep       = 223
    Wake        = 227
  [END KEYS]
[END DIA9801]

#### END Diamond Keybaords ####


#### DTK Keyboards ####

[DTK006] # By Daugirdas
  brandname = "DTK"
  modelname = "006"
  [KEYS]
    Back        = 234
    Calculator  = 161
    File        = 235
    Forward     = 233
    Home        = 178
    Mail        = 236
    Play|Pause  = 162
    PowerOff    = 222
    Search      = 229
    Sleep       = 227
    Stop        = 164
    VolumeDown  = 174
    Volumeup    = 176
    Lamp        = 232
    Media       = 237
    Mute        = 160
    Next        = 153
    Previous    = 144
    Reconnect   = 231
  [END KEYS]
[END DTK006]

#### END DTK Keybaords ####


### Ennyah Keyboards ####

[ENNYAHKBD-1008] #Contrib by Rémi Colomb
  brandname = "Ennyah"
  modelname = "Ennyah Slim Style Keyboard Internet & Multimedia USB"
  [KEYS]
    Home        = 130
    Mail        = 236
    WebBack     = 234
    WebForward  = 233
    Search      = 229
    Refresh     = 121
    Bookmark    = 230
    WebStop     = 232
    VolumeDown  = 165
    VolumeUp    = 158
    Mute        = 166
    Stop        = 151
    Previous    = 164
    Play|Pause  = 159
    Next        = 162
    Option      = 129
    Wake        = 112
    Sleep       = 227
    Power       = 222
  [END KEYS]
[END ENNYAHKBD-1008]

#### END Ennyah Keyboards ####


#### EZ Keyboards ####

[EZ3000]
  brandname = "EZKey"
  modelname = "EZ3000"
  [KEYS]
    Calculator  = 165
    Home        = 159
    Internet    = 178
    CD          = 162
    Mail        = 161
    Mute        = 160
    PPP         = 163
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END EZ3000]

#### END EZ Keyboards ####


#### Fujitsu/Siemens Keyboards ####

[Fuj-A7600]
  brandname = "Fujitsu-Siemens"
  modelname = "Fujitsu/Siemens Amilo A7600+"
  [KEYS]
    Mail = 236
    WWW  = 178
  [END KEYS]
[END Fuj-A7600]

[Fuj-SlimRFD]
  brandname = "Fujitsu-Siemens"
  modelname = "Slim Wireless Keyboard"
  [KEYS]
    AudioPlay|Pause  = 159
    AudioNext        = 162
    AudioMute        = 166
    AudioRaiseVolume = 158
    AudioLowerVolume = 165
    WWW              = 130
    Mail             = 236
    Sleep            = 223
    WakeUp           = 227
    PowerOff         = 222
  [END KEYS]
[END Fuj-SlimRFD]

#### END Fujitsu/Siemens Keyboards ####


#### Gateway Keyboards ####

[GWSK9920]
  brandname = "Gateway SK"
  modelname = "SK-9920"
  [KEYS]
    Internet    = 178
    Mail        = 236
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop        = 164
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END GWSK9920]

#### END Gemini Keyboards ####


#### General Keys Keyboards ####
 
[GK-IK]
  brandname = "GeneralKeys"
  modelname = "Illuminated Keyboard"
  [KEYS]
    Computer    = 235
    Favorites   = 230
    Home        = 178
    InstantMsgr = 237
    Mail        = 236
    Mute        = 160
    Forward     = 233
    Next        = 153
    Open        = 232
    Play        = 162
    Back        = 234
    Previous    = 144
    Reload      = 231
    Search      = 229
    Sleep       = 223
    Stop        = 164
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END GK-IK]

#### END General Keys Keyboards ####


#### Genius Keyboards ####

[GENKB-138]
  brandname = "Genius"
  modelname = "Genius Internet Keyboard KB-138 (9 keys)"
  [KEYS]
    Mail             = 236
    Stop             = 232
    Refresh          = 231
    Back             = 234
    WWW              = 178
    Forward          = 233
    Search           = 229
    Favorites        = 230
    Sleep            = 223
  [END KEYS]
[END GENKB-138]

[GENKB-16E] #
  brandname = "Genius"
  modelname = "KB-16E Scroll Multimedia Keyboard (16 keys)"
  [KEYS]
    Spreadsheet      = 128
    WordProcessor    = 123
    ScrollDown       = 104
    ScrollUp         =  98
    ScrollClick      = 163
    Sleep            = 223
    Back             = 234
    Forward          = 233
    WWW              = 178
    AudioRaiseVolume = 176
    AudioMedia       = 237
    AudioLowerVolume = 174
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    Mail             = 236
    MyComputer       = 235
    Calculator       = 161
  [END KEYS]
[END GENKB-16E]

[GEN-KL0210]
brandname = "Genius"
modelname = "KL-0210"
[KEYS]
    Calculator       = 161
    Mail             = 236
    Favorites        = 230
    AudioMedia       = 237
    AudioPrev        = 144
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioMute        = 160
    MyComputer       = 235
    Refresh          = 231
    Search           = 229
    Sleep            = 223
    Stop             = 232
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    WWW              = 178
    Back             = 234
    Forward          = 233
  [END KEYS]
[END GEN-KL0210]

[GENKB-19E]
  brandname = "Genius"
  modelname = "Genius MM Keyboard KB-19e (19 keys)"
  [KEYS]
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Media       = 237
    Play|Pause  = 162
    Previous    = 144
    Next        = 153
    Stop        = 232
    Mail        = 236
    WebStop     = 232
    Refresh     = 231
    Back        = 234
    Web         = 178
    Forward     = 233
    Search      = 229
    Favorites   = 230
    Sleep       = 223
    Calculator  = 161
    My Computer = 235
  [END KEYS]
[END GENKB-19E]

[GENKB-21E]
  brandname = "Genius"
  modelname = "MM Keyboard KB-21E (21 keys)"
  [KEYS]
    Word        = 147
    Excel       = 148
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
    Previous    = 144
    Next        = 153
    Media       = 237
    Play        = 162
    Stop        = 164
    Mail        = 236
    WebStop     = 232
    WebRefresh  = 231
    WebBack     = 234
    Internet    = 178
    WebForward  = 233
    Search      = 229
    Favorites   = 230
    Sleep       = 223
    Calculator  = 161
    MyComputer  = 235
  [END KEYS]
[END GENKB-21E]

[GENKWD-910]
  brandname = "Genius"
  modelname = "MM Keyboard KWD-910 (16 keys)"
  [KEYS]
    Back        = 163
    Play        = 162
    Stop        = 164
    Forward     = 161
    Eject       = 176
    VolumeDown  = 153
    VolumeUp    = 146
    Mute        = 160
    Screensaver = 166
    Calculator  = 151
    Mail        = 174
    WebBack     = 165
    Internet    = 178
    WebForward  = 158
    Sleep       = 223
    Wake        = 227
  [END KEYS]
[END GENKWD-910]

#### END Genius Keyboards ####


#### GPT Keyboards ####

[GPT-Intl]
  brandname = "GPT"
  modelname = "Intelligent Keyboard"
  [KEYS]
    AudioPrev        = 144
    AudioStop        = 164
    AudioPlay|Pause  = 162
    AudioNext        = 153
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    WWW              = 178
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Search           = 229
    Favorites        = 230
    Mail             = 236
    MyComputer       = 235
    Calculator       = 161
    Sleep            = 223
    Wake             = 227
  [END KEYS]
[END GPT-Intl]

#### END GPT Keyboards ####


#### Graytion Keyboards ####

[GTN-GP9110]
  brandname = "Gyration"
  modelname = "GP9110 Keyboard"
  [KEYS]
    Back        = 234
    Favorites   = 230
    Forward     = 233
    Mail        = 236
    Mute        = 166
    Next        = 162
    Play|Pause  = 159
    Previous    = 164
    Refresh     = 121
    Search      = 229
    Stop        = 151
    WebStop     = 232
    VolumeDown  = 165
    VolumeUp    = 158
    WebHome     = 130
  [END KEYS]
[END GTN-GP9110]

[GTN-Mobile]
  brandname = "Gyration"
  modelname = "Mobile & Ultra Cordless Keyboard"
  [KEYS]
    Back        = 234
    Favorites   = 230
    Forward     = 233
    Mail        = 236
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Refresh     = 231
    Search      = 122
    Stop        = 164
    VolumeDown  = 174
    VolumeUp    = 176
    Web|Home    = 130
    WebStop     = 232
  [END KEYS]
[END GTN-Mobile]

#### END Graytion Keyboards ####


#### Hewlett-Packard  Keyboards ####

[HP0113]
  brandname = "Hewlett-Packard"
  modelname = "HP KB-0133 keyboard"
  [KEYS]
    Internet    = 163
    Home        = 159
    Search      = 154
    Mail        = 158
    Communities = 147
    Market      = 148
    Meeting     = 149
    News        = 155
  [END KEYS]
[END HP0113]

[HPMCEK] #Indiboi
  brandname = "Hewlett-Packard"
  modelname = "Media Center Edition Keyboard (24 keys)"
  [KEYS]
    Standby     = 223
    User        = 172
    HP          = 148
    Help        = 166
    Photo       = 159
    Music       = 150
    Video       = 185
    Shopping    = 158
    Sports      = 146
    Finance     = 167
    Connect     = 178
    Search      = 229
    Chat        = 149
    Email       = 236
    Eject1      = 152
    Eject2      = 131
    Record      = 134
    Play|Pause  = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
  [END KEYS]
[END HPMCEK]

[HP2501]
  brandname = "Hewlett-Packard"
  modelname = "SK-2501 MultiMedia Keyboard (13 keys)"
  [KEYS]
    Internet    = 178
    Search      = 151
    Tools       = 146
    Mail        = 158
    UserDefined1 = 163
    UserDefined2 = 162
    UserDefined3 = 164
    UserDefined4 = 161
    Lock        = 165
    Info        = 166
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
  [END KEYS]
[END HP2501]

[HP2505]
  brandname = "Hewlett-Packard"
  modelname = "SK-2505 Internet Keyboard (14 keys)"
  [KEYS]
    Play        = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    Eject       = 152
    Mail        = 158
    Internet    = 178
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
    Sleep       = 165
  [END KEYS]
[END HP2505]

[HP2506] # By Hobo Johs
  brandname = "Hewlett-Packard"
  modelname = "SK-2506 Internet Keyboard (23 keys)"
  [KEYS]
    Play|Pause  = 162
    Stop        = 164
    Eject       = 152
    Previous    = 163
    Next        = 161
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Email       = 173
    People      = 149
    Search      = 148
    Connect     = 150
    Finance     = 178
    Entertainment = 146
    Shopping    = 158
    Fax         = 165
    Print       = 144
    Find        = 153
    Standby     = 223
    Help        = 166
    HP          = 151
    UserDefined1 = 232
    UserDefined2 = 159
  [END KEYS]
[END HP2506]

[HPOXE3GF] # by Gavriel Fleischer
  brandname = "Hewlett Packard"
  modelname = "HP Omnibook XE3-GF"
  [KEYS]
    Help        = 243
    Launch      = 244
    Mail        = 236
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop|Eject  = 164
    VolumeDown  = 174
    VolumeUp    = 176
    WWW         = 178
  [END KEYS]
[END HPOXE3GF]

[HPOBXE41] # Adrian Neumaier
  brandname = "Hewlett Packard"
  modelname = "HP Omnibook XE-4100 OneTouch Keys"
  [KEYS]
    WWW         = 178
    Mail        = 236
    TV          = 243
    Lock        = 241
    Help        = 240
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
  [END KEYS]
[END HPOBXE41]

[HPXT1000] # by Ben Reiter
  brandname = "Hewlett-Packard"
  modelname = "HP Omnibook XT1000"
  [KEYS]
    Mp3         = 241
    Help        = 242
    Entertainment = 244
    Security    = 243
    Mail        = 232
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop|Eject  = 164
    VolumeDown  = 174
    VolumeUp    = 176
    WWW         = 178
    TouchpadOn  = 239
    TouchpadOff = 238
  [END KEYS]
[END HPXT1000]

#### END Hewlett-Packard Keyboards ####


#### IBM keyboards ####

[IBMRAII]
  brandname = "IBM"
  modelname = "Rapid Access II"
  [KEYS]
    Internet    = 165
    InternetShopping = 166
    IBMWebSupport = 178
    WorldBook   = 151
    Option      = 176
    Help        = 174
    Standby     = 223
    Mute        = 158
    Stop        = 160
    Play|Pause  = 162
    Back        = 164
    Forward     = 146
    VolumeDown  = 161
    VolumeUp    = 163
    UserDefined1 = 117
  [END KEYS]
[END IBMRAII]

#### END IBM Keyboards ####


#### IDream Keyboards ####

[ID-KBF21]
  brandname = "IDream"
  modelname = "ID-KBF21 Keyboard"
  [KEYS]
    Back             = 234
    Calculator       = 161
    AudioLowerVolume = 174
    Mail             = 236
    Favorites        = 230
    Forward          = 233
    AudioRaiseVolume = 176
    AudioMedia       = 237
    AudioStop        = 164
    AudioMute        = 160
    MyComputer       = 235
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    Refresh          = 231
    Search           = 229
    Sleep            = 223
    Stop             = 232
    WWW              = 178
  [END KEYS]
[END ID-KBF21]

#### END IDream Keyboards ####


#### Itron Keyboards ####

#This is the same as Scorpius's Advance Scorpius K1 -- cut&paste
[ITRON-GK1]
  brandname = "Itron"
  modelname = "Itron Gemini K1"
  [KEYS]
    AudioPrev        = 144
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioNext        = 153
    AudioMedia       = 237
    AudioLowerVolume = 174
    AudioMute        = 160
    AudioRaiseVolume = 176
    Wake             = 227
    Sleep            = 223
    PowerOff         = 222
    Calculator       = 161
    MyComputer       = 235
    Mail             = 236
    Favorites        = 230
    WWW              = 178
    Back             = 234
    Forward          = 233
    Stop             = 232
    Reload           = 231
    Search           = 229
  [END KEYS]
[END ITRON-GK1]

#### END Itron Keyboards ####


#### Kensiko Keyboards ####

[KKO-MCK2000] # Contributed by Marc DellaVolpe
  brandname = "Kensiko"
  modelname = "mck-2000"
  [KEYS]
    Calculator  = 161
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop        = 164
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END KKO-MCK2000]

#### END Kensiko Keyboards ####

#### Kensington Keyboards ####

[KNS-CTMM]
  brandname = "Kensington"
  modelname = "Comfort Type Multimedia"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Search           = 229
    Favorites        = 230
    WWW              = 178
    Mail             = 236
    AudioPrev        = 144
    AudioStop        = 164
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
    AudioMedia       = 237
    MyComputer       = 235
    Calculator       = 161
    Sleep            = 223
  [END KEYS]
[END KNS-CTMM]

[KEN64355]
  brandname = "Kensington"
  modelname = "Comfort Type Wireless Keyboard 64355"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    WWW              = 178
    Search           = 229
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
    Favorites        = 230
    Mail             = 236
    MyComputer       = 235
  [END KEYS]
[END KEN64355]

#### END Kensington Keyboards ####


##### Keytronic keyboards ####

[KTKTMPS202BI] # By Frank Bruder
  brandname = "KeyTronic"
  modelname = "KTMPS202BI"
  [KEYS]
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Calculator  = 161
    EMail       = 236
    HomePage    = 178
    Play|Pause  = 162
    MediaPlayer = 237
    Stop        = 164
    Forward     = 153
    Rewind      = 144
    My Desktop  = 235
    My Favorites = 230
    Sleep       = 223
    WebBack     = 234
    WebForward  = 233
    WebRefresh  = 231
    WebStop     = 232
    WebSearch   = 229
  [END KEYS]
[END KTMPS202BI]

#### END Keytronic Keyboards ####


#### Labtec Keyboards ####

[LAB_WDE] # By Jose Jorge
  brandname = "Labtec"
  modelname = "Wireless Desktop Edge"
  [KEYS]
    Sleep            = 223
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    AudioMute        = 160
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    WWW              = 178
    Mail             = 236
    Search           = 229
    MyComputer       = 235
  [END KEYS]
[END LAB_WDE]

[LAB-UFK]
  brandname = "Labtec"
  modelname = "Labtec Ultra-Flat Keyboard"
  [KEYS]
    WWW              = 178
    AudioStop        = 164
    AudioPlay|Pause  = 162
    AudioNext        = 153
    AudioPrev        = 144
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMute        = 160
    Mail             = 236
  [END KEYS]
[END LAB-UFK]

#### END Labtec Keyboards ####


#### Leadership CA Keyboards ####

[LS-GS] # Contributed by Eduardo J. Ortega
  brandname = "Leadership Computer Accesories"
  modelname = "Goldship"
  [KEYS]
    CD          = 175
    Previous    = 145
    Stop        = 158
    Play|Pause  = 146
    Next        = 159
    VolumeDown  = 152
    VolumeUp    = 147
    Mute        = 163
    Menu        = 172
    Close       = 148
    WWW         = 168
    Email       = 167
    Messenger   = 173
    Search      = 177
    Help        = 166
    DOS         = 165
    User        = 151
    Sleep       = 223
    WakeUp      = 227
    Power       = 222
  [END KEYS]
[END LS-GS]

[LS-SMALL]
  brandname = "Leadership Computer Accesories"
  modelname = "SmallKeyboard"
  [KEYS]
    Forward          = 234
    Back             = 233
    Close            = 232
    Refresh          = 231
    Search           = 229
    Mail             = 230
    WWW              = 178
    Documents        = 236
    Terminal         = 235
    Calculator       = 161
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPrev        = 144
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioMute        = 160
    AudioMedia       = 237
    PowerOff         = 222
    Sleep            = 223
    WakeUp           = 227
  [END KEYS]
[END LS-SMALL]

#### END Leadership CA Keyboards ####


#### Logitech keyboards ####

[LTAcc]
  brandname = "Logitech"
  modelname = "Access"
  [KEYS]
    Mail        = 236
    Media       = 237
    SMS         = 145
    Mute        = 160
    Home        = 178
    WebCam      = 146
  [END KEYS]
[END LTAcc]

[LTAK]
  brandname = "Logitech"
  modelname = "Access Keyboard"
  [KEYS]
    Sleep       = 223
    Email       = 236
    SMS         = 145
    WebCam      = 146
    My Home     = 178
    Search      = 229
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
    Media       = 237
    Previous    = 144
    Next        = 153
    Play|Pause  = 162
    Stop        = 164
    New         = 187
    Reply       = 188
    Forward     = 118
    Send        = 119
    My Computer = 195
    My Documents = 196
    My Pictures = 215
    My Music    = 216
  [END KEYS]
[END LTAK]

[LTCMKg] # By"raveman2000" 
  brandname = "Logitech"
  modelname = "Corded Media Keyboard (GERMAN) Y-BH52"
  [KEYS]
    Sleep            = 223
    Mail             = 236
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMedia       = 237
    Favorites        = 230
    AudioPrev        = 144
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioStop        = 164
    Search           = 229
    Home             = 178
    Calculator       = 161
    Back             = 234
    Forward          = 233
#no xev for the 2nd function of all Fxx and messenger
  [END KEYS]
[END LTCMKg]

[LTCD]
  brandname = "Logitech"
  modelname = "Cordless Desktop"
  [KEYS]
    Sleep       = 223
    Internet    = 130
    Mail        = 236
    Search      = 229
    Go          = 230
    Mute        = 166
    VolumeDown  = 165
    VolumeUp    = 158
    Play        = 159
    Stop        = 151
    Previous    = 164
    Next        = 162
  [END KEYS]
[END LTCD]

[LTCDC]
  brandname = "Logitech"
  modelname = "Cordless Desktop Comfort"
  [KEYS]
    Sleep            = 223
    Home             = 178
    Mail             = 236
    Search           = 229
    Favorites        = 230
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    WinLeft          = 115
    WinRight         = 116
    Logitech         = 161
  [END KEYS]
[END LTCDC]

[LTCDDO] # By"Romain BISSEY"
  brandname = "Logitech"
  modelname = "Cordless Desktop Deluxe Optical"
  [KEYS]
    Sleep       = 223
    Mail        = 236
    Messenger-SMS = 145
    Webcam      = 146
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Media       = 237
    Recieve     = 178
    Reload      = 229
    F1          = 187
    F2          = 188
    F3          = 118
    F4          = 119
    F5          = 120
    F6          = 121
    F7          = 122
    F8          = 194
    F9          = 195
    F10         = 196
    F11         = 215
    F12         = 216
  [END KEYS]
[END LTCDDO]

[LTCDDOg] # Joerg Gutowski
  brandname = "Logitech"
  modelname = "Cordless Desktop Deluxe Optical (German)"
  [KEYS]
    Mail        = 236
    F/Bilder    = 215
    F/Bildschirm = 195
    F/Dateien   = 196
    F/E-Mail    = 119
    F/F2        = 188
    F/F3        = 118
    F/Musik     = 216
    F/Play|F/Pause = 122
    F/Stop      = 194
    F/neues     = 187
    F/vor       = 121
    F/zurck     = 120
    Media       = 237
    Messenger   = 145
    Startseite  = 178
    Suchen      = 229
    Ton         = 160
    User        = 223
    Webkamera   = 146
    Lauter      = 176
    Leiser      = 174
  [END KEYS]
[END LTCDDOg]

[LTCDiT]
  brandname = "Logitech"
  modelname = "Cordless Desktop iTouch"
  [KEYS]
    Sleep       = 223
    Finance     = 147
    My Sites    = 148
    Communities = 149
    Favorites   = 230
    Previous    = 144
    Next        = 153
    Media       = 237
    VolumeUp    = 176
    VolumeDown  = 174
    Mute        = 160
    Play        = 162
    Stop        = 164
    VendorHome  = 146
    Mail        = 236
    Shop        = 145
    Search      = 229
    Home        = 178
  [END KEYS]
[END LTCDiT]

[LTCDNO]
  brandname = "Logitech"
  modelname = "Cordless Desktop Navigator Optical"
  [KEYS]
    Sleep       = 223
    Mail        = 236
    SMS         = 145
    WebCam      = 146
    iTouch      = 147
    Search      = 229
    Shop	= 148
    Favorites   = 230
    Home        = 178
    Previous    = 144
    Next        = 153
    Media	= 237
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Play|Pause  = 162
    Stop        = 164
    FTaste-F1   = 187
    FTaste-F2   = 188
    FTaste-F3   = 118
    FTaste-F4   = 119
    FTaste-F5   = 120
    FTaste-F6   = 121
    FTaste-F7   = 122
    FTaste-F8   = 194
    FTaste-F9   = 195
    FTaste-F10  = 196
    FTaste-F11  = 215
    FTaste-F12  = 216
  [END KEYS]
[END LTCDNO]

[LTCDO]
  brandname = "Logitech"
  modelname = "Cordless Desktop Optical"
  [KEYS]
    Go           = 233
    WebBack      = 234
    Wheelbutton  = 150
    Sleep        = 223
    Finance      = 147
    My Sites     = 148
    Social       = 149
    Favorites    = 230
    Previous     = 144
    Next         = 153
    Media        = 237
    VolumeDown   = 174
    VolumeUp     = 176
    Mute         = 160
    Play         = 162
    Stop         = 164
    iTouch       = 146
    Mail         = 236
    Shop         = 145
    Search       = 229
    Home         = 178
  [END KEYS]
[END LTCDO]

[LTCDP]
  brandname = "Logitech"
  modelname = "Cordless Desktop Pro"
  [KEYS]
    Sleep        = 223
    Internet     = 178
    Mail         = 236
    Search       = 229
    Go           = 230
    Mute         = 160
    VolumeDown   = 174
    VolumeUp     = 176
    Play|Pause   = 162
    Stop         = 164
    Previous     = 144
    Next         = 153
    VendorHome   = 161
  [END KEYS]
[END LTCDP]

[LTCDPa]
  brandname = "Logitech"
  modelname = "Cordless Desktop Pro (alternate option)"
  [KEYS]
    Sleep        = 223
    Internet     = 130
    Mail         = 236
    Search       = 229
    Go           = 230
    Mute         = 166
    VolumeDown   = 165
    VolumeUp     = 158
    Play         = 159
    Stop         = 151
    Previous     = 164
    Next         = 162
    VendorHome   = 161
  [END KEYS]
[END LTCDPa]

[LTCFN]
  brandname = "Logitech"
  modelname = "Cordless Freedom/Desktop Navigator"
  [KEYS]
    Finance     = 147
    My Sites    = 148
    Communities = 149
    Favorites   = 230
    Previous    = 144
    Next        = 153
    Media       = 237
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Play        = 162
    Stop        = 164
    iTouch      = 146
    Mail        = 236
    Shopping    = 145
    Search      = 229
    Home        = 178
    Sleep       = 233
    ScrollUp    = 98
    ScrollDown  = 104
    ScrollClick = 150
    WebBack     = 234
    WebForward  = 233
  [END KEYS]
[END LTCFN]

[LCDN]
  brandname = "Logitech"
  modelname = "Cordless Desktop Navigator (with expand fuctions key)"
  [KEYS]
    Favorites   = 230
    Forward     = 118
    Home        = 178
    iTouch      = 147
    Mail        = 236
    Media       = 237
    Mute        = 160
    MyDocuments = 196
    MyMusic     = 216
    MyPictures  = 215
    New         = 187
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Print       = 122
    Redo        = 121
    Reply       = 188
    Save        = 194
    Screen      = 195
    Search      = 229
    Send        = 119
    Shopping    = 148
    Sleep       = 223
    SMS         = 145
    Stop        = 164
    Undo        = 120
    VolumeDown  = 174
    VolumeUp    = 176
    Webcam      = 146
  [END KEYS]
[END LCDN]

# Hubert Fink DG7MGY
[LTCDPR]
  brandname = "Logitech"
  modelname = "Cordless Desktop Precision Y-RH35"
  [KEYS]
     Sleep            = 223
     Mail             = 236
     InstantMessanger = 145
     Webcam           = 146
     AudioMute        = 160
     AudioRaiseVolume = 176
     AudioLowerVolume = 174
     AudioMedia       = 237
     WWW              = 178
     Search           = 229
     AltF1            = 187
     AltF2            = 188
     AltF3            = 118
     AltF4            = 119
     AltF5            = 120
     AltF6            = 121
     AltF7            = 122
     AltF8            = 194
     AltF9            = 195
     AltF10           = 196
     AltF11           = 215
     AltF12           = 216
     Custom1          = 115
     Custom2          = 116
   [END KEYS]
[END LTCDPR]

[LTCoiT]
  brandname = "Logitech"
  modelname = "Corded iTouch Keybard (Model?)"
  [KEYS]
    Search           = 229
    WWW              = 130
    Mail             = 236
    AudioMute        = 166
    AudioLowerVolume = 165
    AudioRaiseVolume = 158
    AudioPlay|Pause  = 159
    AudioStop        = 151
    AudioPrev        = 164
    AudioNext        = 162
    Launch0          = 230
    Sleep            = 223
  [END KEYS]
[END LTCoiT]

[LTCiY] # Contributed by Glen Stewart
  brandname  = "Logitech"
  modelname  = "Corded iTouch Y-BC9"
  [KEYS]
    Favorites   = 230
    Home        = 178
    Mail        = 236
    Mute        = 160
    Next        = 153
    Play        = 162
    Power       = 223
    Previous    = 144
    Search      = 229
    Stop        = 164
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END LTCiY]

[LTCED]
  brandname = "Logitech"
  modelname = "Cordless Elite Duo"
  [KEYS]
    Go          = 233
    WebBack     = 234
    Mail        = 236
    SMS         = 240
    WebCam      = 241
    Previous    = 164
    Next        = 162
    Media       = 129
    VolumeUp    = 158
    VolumeDown  = 165
    Mute        = 166
    Play        = 159
    Stop        = 151
    iTouch      = 242
    Search      = 229
    Shopping    = 243
    Favorites   = 230
    Home        = 130
  [END KEYS]
[END LTCED]

[LTCEDB]
  brandname = "Logitech"
  modelname = "Cordless Elite Duo (Black)"
  [KEYS]
    Mail        = 236
    Favorites   = 230
    Media       = 237
    SMS         = 145
    Home        = 178
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Search      = 229
    Shopping    = 148
    Stop        = 164
    UserDefined1 = 223
    VolumeDown  = 174
    VolumeUp    = 176
    WebCam      = 146
    iTouch      = 147
  [END KEYS]
[END LTCEDB]

[LTCi3B]
  brandname	= "Logitech"
  modelname	= "Cordless iTouch 3 Button
  [KEYS]
    Mail        = 236
    Search      = 229
    Internet    = 178
  [END KEYS]
[END LTCi3B]

[LTCiT]
  brandname = "Logitech"
  modelname = "Cordless iTouch Keyboard Y-RB6"
  [KEYS]
    Play|Pause  = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    Mail        = 236
    Home        = 178
    Search      = 229
    Favorites   = 230
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Sleep       = 223
  [END KEYS]
[END LTCiT]

[LCOF]
  brandname = "Logitech"
  modelname = "Cordless Optical Freedom"
  [KEYS]
    Back            = 234
    Mail            = 236
    Favorites       = 230
    Go              = 233
    AudioPrev       = 144
    AudioMedia      = 237
    AudioMute       = 160
    HomePage        = 178
    AudioNext       = 153
    AudioPlay|Pause = 162
    Search          = 229
    Sleep           = 223
    AudioStop       = 164
  [END KEYS]
[END LCOF]

[LTDAK]
  brandname= "Logitech"
  modelname = "Deluxe Access Keyboard"
  [KEYS]
    Sleep           = 223
    Mail            = 236
    SMS             = 145
    WebCam          = 146
    AudioMute       = 160
    VolumeUp        = 176
    VolumeDown      = 174
    AudioMedia      = 237
    WWW             = 178
    Search          = 229
    New             = 187
    Reply           = 188
    Forward         = 118
    Send            = 119
    AduioPrev       = 144
    AudioNext       = 153
    AudioPlay|Pause = 162
    Stop            = 164
    MyComputer      = 195
    Documents       = 196
    Pictures        = 215
    Music           = 216
  [END KEYS]
[END LTDAK]

[LTEPS2]
  brandname = "Logitech"
  modelname = "Elite Keyboard (PS2)"
  [KEYS]
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPrev        = 144
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioMute        = 160
    AudioMedia       = 237
    Mail             = 236
    InstantMessage   = 145
    Webcam           = 146
    iTouch           = 147
    Search           = 229
    Shopping         = 148
    Favorites        = 230
    WWW              = 178
    Sleep            = 223
    Back             = 234
    Go               = 233
    New              = 67
    Reply            = 68
    Forward          = 69
    Send             = 70
    Undo             = 71
    Redo             = 72
    Print            = 73
    Save             = 74
    MyComputer       = 75
    Documents        = 76
    MediaPictures    = 95
    MediaMusic       = 96
  [END KEYS]
[END LTEPS2]

[LTCElite] #Contributed by Chris Johns
  brandname = "Logitech"
  modelname = "Elite Keyboard Y-BF38"
  [KEYS]
    Go          = 233
    Arrow       = 234
    Sleep       = 223
    Email       = 236
    Messenger   = 145
    Webcam      = 146
    Previous    = 144
    Next        = 153
    Media       = 237
    VolumeUp    = 176
    VolumeDown  = 174
    Mute        = 160
    Play|Pause  = 162
    Stop        = 164
    iTouch      = 147
    Search      = 229
    Shopping    = 148
    Favorites   = 230
    MyHome      = 178
  [END KEYS]
[END LCElite]

[LTOIK-SQ33]
  brandname = "Logitech"
  modelname = "Office Internet Keyboard Y-SQ33"
  [KEYS]
    Sleep       = 223
    Documents   = 147
    Spreadsheets = 148
    Webcam      = 154
    Files       = 133
    EMail       = 236
    WWW         = 178
    Calendar    = 149
    Calculator  = 161
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Help        = 187
    Application Left = 188
    Application Right = 118
    ControlPanel = 119
    FileSearch  = 120
    Pictures    = 121
    Desktop     = 122
    Network     = 194
    Previous    = 144
    Stop        = 164
    Play|Pause  = 162
    Next        = 153
    WebBack     = 234
    WebForward  = 233
    ParenLeft   = 101
    ParenRight  = 228
  [END KEYS]
[END LTOIK-SQ33]

[LIKS]
  brandname = "Logitech"
  modelname = "Internet Keyboard Standard"
  [KEYS]
    Logitech    = 165
    Favorite    = 166
    Back        = 144
    Find        = 146
    Forward     = 162
    History     = 178
    Home        = 163
    Hotlinks    = 160
    Favorites   = 152
    Go          = 161
    Print       = 151
    Refresh     = 153
    ScrollDown  = 174
    ScrollUp    = 176
    Search      = 158
    Send To Back = 163
    Stop        = 164
    Internet    = 250
  [END KEYS]
[END LIKS]

[LTIK]
  brandname = "Logitech"
  modelname = "Internet Keyboard"
  [KEYS]
    Play|Pause  = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    Mail        = 236
    Home        = 178
    Search      = 229
    Go          = 230
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Sleep       = 223
  [END KEYS]
[END LTIK]

[LTIK-ST39]
  brandname = "Logitech"
  modelname = "Internet Keyboard Y-ST39"
  [KEYS]
    Search           = 229
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Files            = 133
  [END KEYS]
[END LTIK-ST39]

[LTIKeurope]
  brandname = "Logitech"
  modelname = "Internet Keyboard (European)"
  [KEYS]
    Search      = 229
    Files       = 133
    E-Mail      = 236
    WWW         = 178
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END LTIKeurope]


[LTINK]
  brandname = "Logitech"
  modelname = "Internet Navigator Keyboard"
  [KEYS]
    Play|Pause  = 162
    Previous    = 144
    Next        = 153
    Stop        = 164
    Mail        = 236
    Home        = 178
    Search      = 229
    Go          = 233
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
    Sleep       = 223
    WebBack     = 234
    Finance     = 147
    My Sites    = 148
    Communities = 149
    Favorites   = 230
    Media       = 237
    VendorHome  = 146
    Market      = 145
  [END KEYS]
[END LTINK]

[LTINKSE]
  brandname = "Logitech"
  modelname = "Internet Navigator Keyboard Special Edition"
  [KEYS]
  # Left-hand side:
    Go          = 233
    WebBack     = 234
    Shellpress  = 150
    Sleep       = 223
    Mail        = 236
    SMS         = 145
    WebCam      = 146
  # Right-hand side:
    iTouch      = 147
    Search      = 229
    Shopping    = 148
    Favorites   = 230
    Home        = 178
  # Top:
    Previous    = 144
    Next        = 153
    Play|Pause  = 162
    Stop        = 164
    Media	= 237
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
  # F-Keys UnLocked:
    New         = 187
    Reply       = 188
    Forward     = 118
    Send        = 119
    Undo        = 120
    Redo        = 121
    Print       = 122
    Save        = 194
    My Computer = 195
    My Documents = 196
    My Pictures = 215
    My Music    = 216
  [END KEYS]
[END LTINKSE]

[LTINKSEPS2]
  brandname = "Logitech"
  modelname = "Internet Navigator Keyboard SE PS2"
  [KEYS]
    Go          = 233
    WebBack     = 234
    User        = 223
    Email       = 236
    Messenger   = 145
    Webcam      = 146
    MediaBack   = 144
    MediaForward = 153
    Media       = 237
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Play|Pause  = 162
    Stop        = 164
    iTouch      = 147
    Search      = 229
    Market      = 148
    Favorites   = 230
    Home        = 178
  # 2nd functions of the F keys
    NewFile     = 187
    PreviousPeer = 188
    NextPeer    = 118
    NewMail     = 119
    Back        = 120
    Forward     = 121
    Print       = 122
    Save        = 194
    Monitor     = 195
    OpenFile    = 196
    OpenPicture = 215
    OpenMusic   = 216
  [END KEYS]
[END LTINKSEPS2]
 
[LTINKSEUSB]
  brandname = "Logitech"
  modelname = "Internet Navigator Keyboard SE USB"
  [KEYS]
    Go          = 233
    WebBack     = 234
    User        = 223
    Email       = 236
    MediaBack   = 164
    MediaForward = 162
    Media       = 129
    VolumeDown  = 165
    VolumeUp    = 158
    Play|Pause  = 159
    Stop        = 151
    Search      = 229
    Favorites   = 230
    Home        = 130
  # 2nd functions of the F keys
    NewFile     = 196
    PreviousPeer = 197
    NextPeer    = 110
    NewMail     = 202
    Back        = 103
    Forward     = 101
    Print       = 212
    Save        = 213
    Monitor     = 111
    OpenFile    = 214
    OpenPicture = 215
    OpenMusic   = 216
  [END KEYS]
[END LTINKSEUSB]

[LPDO]
  brandname = "Logitech"
  modelname = "Premium Desktop Optical"
  [KEYS]
    Search           = 229
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    Files            = 133
  [END KEYS]
[END LPDO]
 
#LTUF features: it has laptop keys Logitech Ultraflat keyboard is an OEM keyboard
#If you have any information about the configuration it was ment to be sold with,
#please let me know at snowball [at] neobee.net Contributed by -V-O-Y-A-G-E-R-
[LTUF]
  brandname = "Logitech"
  modelname = "UltraX Flat / Y-SX49"
  [KEYS]
    AudioMedia      =237
    AudioPlay|Pause =162
    AudioMute       =160
    Favorites       =230
    Mail            =236
    WWW             =178
  [END KEYS]
[END LTUF]

#### END Logitech Keyboards ####


#### Medion keyboards ####

[MDKB9908]
  brandname = "Medion"
  modelname = "kb-9908"
  [KEYS]
    Internet    = 178
    Mail        = 236
    Mute        = 160
    Search      = 229
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END MKB9908]

[MD5351]
  brandname = "Medion"
  modelname = "MD5351"
  [KEYS]
    Calculator  = 161
    Media       = 237 
    Computer    = 235
    Folder      = 230
    Home        = 178
    Mail        = 236
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Sleep       = 223
    Stop        = 164
    VolumeDown  = 174
    VolumeUp    = 176
    WebBack     = 234
    WebForward  = 233
    WebSeload   = 231
    WebSearch   = 229
    WebStop     = 232
  [END KEYS]
[END MD5351]

[MD40287]
  brandname = "Medion"
  modelname = "Wireless Deskset 40287"
  [KEYS]
    WebBack     = 234
    Browser     = 229
    WebForward  = 233
    Home        = 178
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop        = 164
    Mail        = 236
    NewFolder   = 230
    Media       = 237
    Control     = 235
    Calc        = 161
    Reload      = 231
    Sleep       = 223
    WebStop     = 232
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
  [END KEYS]
[END MD40287]

#### END Medion Keyboards ####


#### Memorex keyboards ####

[MX1998]
  brandname = "Memorex"
  modelname = "MX1998"
  [KEYS]
    Stop       = 164
    Play       = 162
    Previous   = 144
    Next       = 153
    VolumeUp   = 176
    VolumeDown = 174
    Mute       = 160
    Power      = 222
    Suspend    = 223
    Coffee Break = 250
    Wake       = 215
    Internet   = 178
    Calculator = 165
    Xfer       = 152
    Dos        = 232
    My Documents = 161
    Back       = 146
    Record     = 158
    Game       = 163
    Close      = 151
    Menu       = 166
    ScrollUp   = 98
    ScrollDown = 104
  [END KEYS]
[END MX1998]

[MX2500]
  brandname = "Memorex"
  modelname = "MX2500 EZ-Access Keyboard"
  [KEYS]
    Sleep       =223
    Wake        =235
    Power Off   =222
    Dos         =148
    Documents   =159
    News        =166
    Internet    =178
    Xfer        =152
    Mail        =236
    Clear       =146
    Phone       =147
    Calculator  =161
    Previous    =144
    Next        =153
    VolumeUp    =176
    VolumeDown  =174
    Mute        =160
    Play|Pause  =162
    Rotate Windows =237
    Stop        =164
    Close       =151
    Eject       =158
    LWindows    =115
    RWindows    =116
    Properties  =117
  [END KEYS]
[END MX2500]

[MX2750]
  brandname = "Memorex"
  modelname = "MX2750"
  [KEYS]
    Power      = 222
    Sleep      = 223
    Wake       = 227
    Internet   = 178
    Search     = 229
    Favorites  = 230
    WebBack    = 234
    WebForward = 233
    Mail       = 236
    VolumeUp   = 176
    VolumeDown = 174
    Stop       = 164
    Mute       = 160
    Play|Pause = 162
    Previous   = 144
    Next       = 153
  [END KEYS]
[END MX2750]

#### END Memorex Keyboards ####


#### Mico Innovations Keyboards ####

[MI-KB985W]
  brandname = "Micro Innovations"
  modelname = "KB985W"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Search           = 229
    Favorites        = 230
    WWW              = 178
    Mail             = 236
    MyComputer       = 235
    Sleep            = 223
    Wake             = 227
    Calculator       = 161
    AudioMute        = 160
    AudioMedia       = 237
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END MI-KB985W]

#### END Micro Innovations Keyboards ####


#### Microsoft keyboards ####

[MIK]
  brandname = "Microsoft"
  modelname = "Internet Keyboard"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    Mail        = 236
    Internet    = 178
    My Computer = 235
    Calculator  = 161
    Search      = 229
    Favorites   = 230
    Sleep       = 223
  [END KEYS]
[END MIK]

[MIKpro] # MIKpro Driver Completed By SIR_Taco <sir_taco@yahoo.ca>
  brandname = "Microsoft"
  modelname = "Internet Keyboard Pro"
  [KEYS]
  # MultiMedia Section -- Right Side
    Previous    = 144
    Play|Pause  = 162
    Stop        = 164
    Next        = 153
    Media       = 237
    VolumeUp    = 176
    VolumeDown  = 174
    Mute        = 160
  # Internet Section -- Left Side
    Home        = 178
    Mail        = 236
    Favorites   = 230
    Search      = 229
    WebStop     = 232
    WebBack     = 234
    WebForward  = 233
    Refresh     = 231
  # My Computer Section -- Far Right
    My Computer = 235
    Calculator  = 161
    Sleep       = 223
  [END KEYS]
[END MIKpro]

[MIKproUSB]
  brandname = "Microsoft"
  modelname = "Internet Keyboard Pro USB"
  [KEYS]
  # MultiMedia Section -- Right Side
    Previous    = 164
    Play|Pause  = 159
    Stop        = 151
    Next        = 162
    Media       = 129
    VolumeUp    = 158
    VolumeDown  = 165
    Mute        = 166
  # Internet Section -- Left Side
    Home        = 130
    Mail        = 236
    Favorites   = 230
    Search      = 229
    WebStop     = 232
    WebBack     = 234
    WebForward  = 233
    Refresh     = 121
  # My Computer Section -- Far Right
    My Computer = 111
    Calculator  = 161
    Sleep       = 227
  [END KEYS]
[END MIKproUSB]

[MIKproSE] 
  brandname = "Microsoft"
  modelname = "Internet Keyboard Pro (Swedish)"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    Refresh     = 121
    Search      = 229
    Favorites   = 230
    Home        = 130
    Mail        = 236
    Mute        = 166
    VolumeDown  = 165
    VolumeUp    = 158
    Play|Pause  = 159
    Stop        = 151
    Previous    = 164
    Next        = 162
    Media       = 129
    My Computer = 111
    Calculator  = 161
    Sleep       = 227
  [END KEYS]
[END MIKproSE]

[MMK] # By Darryl Bleau
  brandname = "Microsoft"
  modelname = "Multimedia Keyboard"
  [KEYS]
  # 'My' Keys
    My Documents = 101
    My Pictures = 228
    My Music    = 188
  # 'Media' Keys
    Mute        = 160
    Play|Pause  = 162
    Stop        = 164
    VolumeUp    = 176
    VolumeDown  = 174
    Previous    = 144
    Next        = 153
    Media       = 237
  # 'App' Keys
    Mail        = 236
    Home        = 178
    Messenger   = 133
  # 'Quick' Keys
    Calculator  = 161
    Logoff      = 150
    Sleep       = 223
  [END KEYS]
[END MMK]

[MMK-1A]
  brandname = "Microsoft"
  modelname = "Multimedia Keyboard 1.0A"
  [KEYS]
    Calculator       = 161
    AudioNext        = 153
    Mail             = 236
    AudioMedia       = 237
    AudioMute        = 160
    MyDocuments      = 239
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    Sleep            = 223
    AudioStop        = 164
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    WWW              = 178
  [END KEYS]
[END MMK-1A]

[MMNK] # Contributed by Howard Hamlyn
  brandname = "Microsoft"
  modelname = "Multimedia Natural Keyboard"
  [KEYS]
    My Documents = 101
    My Pictures = 228 
    My Music    = 188
    Mute        = 160
    Play|Pause  = 162
    Stop        = 164
    VolumeUp    = 176 
    VolumeDown  = 174
    Previous    = 144
    Next        = 153
    Media       = 237 
    Mail        = 236 
    Web|Home    = 178  
    Messenger   = 133 
    Calculator  = 161 
    Log off     = 150 
    Sleep       = 223
  # The alternate functions of the F1-F12 keys when F-Lock is off.
    Help        = 187
    Undo        = 136 
    Redo        = 135 
    New         = 119
    Open        = 120
    Close       = 121
    Reply       = 122 
    Forward     = 194
    Send        = 195 
    Spell       = 163 
    Save        = 215
    Print       = 216 
  [END KEYS]
[END MMNK]

[MMNKP] # By Colin Nickerson
  brandname = "Microsoft"
  modelname = "Multimedia Natural Pro"
  [KEYS]
    Calculator  = 161
    Close       = 121
    Forward     = 194
    Help        = 187
    Log Off     = 150
    Mail        = 236
    Media       = 237
    Messenger   = 133
    Mute        = 160
    My Documents = 101
    My Music    = 188
    My Pictures = 228
    New         = 119
    Next        = 153
    Open        = 120
    Play|Pause  = 162
    Previous    = 144
    Print       = 216
    Redo        = 135
    Reply       = 122
    Save        = 215
    Send        = 195
    Sleep       = 223
    Spell       = 163
    Stop        = 164
    Undo        = 136
    VolumeDown  = 174
    VolumeUp    = 176
    Web|Home    = 178
  END KEYS]
[END MMNKP]

[MNKpro]
  brandname = "Microsoft"
  modelname = "Natural Keyboard Pro"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    Refresh     = 231
    Media       = 237
    Previous    = 144
    Stop        = 164
    Play|Pause  = 162
    Next        = 153
    VolumeUp    = 176
    VolumeDown  = 174
    Mute        = 160
    Home        = 178
    My Computer = 235
    Mail        = 236
    Search      = 229
    Favorites   = 230
    Calculator  = 161
    Sleep       = 223
  [END KEYS]
[END MNKpro]

[MNKproUSB]
  brandname = "Microsoft"
  modelname = "Natural Keyboard Pro USB"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    Refresh     = 121
    Media       = 129
    Previous    = 164
    Stop        = 151
    Play        = 159
    Next        = 162
    VolumeUp    = 158
    VolumeDown  = 165
    Mute        = 166
    Web Home    = 130
    My Computer = 111
    Mail        = 236
    Search      = 229
    Favorites   = 230
    Calculator  = 161
    Sleep       = 227
  [END KEYS]
[END MNKproUSB]

[MOK]
  brandname = "Microsoft"
  modelname = "Office Keyboard"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    Cut         = 188
    Copy        = 248
    Paste       = 109
    Application Left = 212
    Application Right = 101
    Word        = 196
    Excel       = 197
    Internet    = 130
    Mail        = 236
    Calendar    = 114
    Home        = 215
    Calculator  = 161
    Mute        = 166
    VolumeUp    = 165
    VolumeDown  = 158
    Logoff      = 202
    Sleep       = 223
    Help        = 226
    Office Home = 237
    Taskpane    = 213
    New         = 216
    Open        = 217
    Close       = 218
    Reply       = 241
    Forward     = 242
    Send        = 243
    Spell       = 214
    Save        = 228
    Print       = 231
    Undo        = 103
    Redo        = 240
  [END KEYS]
[END MOK]

[MWDEK]  # Filled in by benedict@hawaii.rr.com Tom Benedict
  brandname = "Microsoft"
  modelname = "Wireless Desktop Excecutive Keyboard"
  [KEYS]
  # Multimedia
    Play|Pause  = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
    Mute        = 160
    Media       = 237
    VolumeUp    = 176
    VolumeDown  = 174
  # Web
    Web|Home    = 178
    WebBack     = 234
    WebForward  = 233
    Show Favorites = 248
    My Favorites 1 = 243
    My Favorites 2 = 244
    My Favorites 3 = 245
    My Favorites 4 = 246
    My Favorites 5 = 247
  # Applications
    My Documents = 101
    My Pictures = 228
    My Music    = 188
    Mail        = 236
    Messenger   = 133
    Calculator  = 161
    Logoff      = 150
    Sleep       = 223
  # F-Key Function
    Help        = 187
    Undo        = 136
    Redo        = 135
    New         = 119
    Open        = 120
    Close       = 121
    Reply       = 122
    Fwd         = 194
    Send        = 195
    Spell       = 163
    Save        = 215
    Print       = 216
  [END KEYS]
[END MWDEK]

[MWMK1]
  brandname = "Microsoft"
  modelname = "Wireless MultiMedia Keyboard 1.0A (User Defined)"
  [KEYS]
    AudioMedia       = 237
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioFFwd        = 153
    AudioNext        = 194
    AudioPrev        = 144
    AudioLowerVolume = 174
    AudioRaiseVolume = 129
    AudioMute        = 160
    Documents        = 101
    Pictures         = 228
    Music            = 129
    Sleep            = 223
    LogOff           = 150
    Calculator       = 161
    WWW              = 178
    Messenger        = 133
    MailSend         = 195
    MailReply        = 129
    SpellCheck       = 163
    New              = 119
    Open             = 120
    Close            = 121
    Save             = 163
    Print            = 216
    Undo             = 136
    Redo             = 129
    Help             = 187
  [END KEYS]
[END MWMK1]

[MS-WNMK]
  brandname = "Microsoft"
  modelname = "Wireless Natural Multimedia Keyboard"
  [KEYS]
    MyDocuments      = 239
    MyPictures       = 183
    MyMusic          = 184
    AudioMute        = 160
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    AudioPrev        = 144
    AudioNext        = 153
    AudioMedia       = 237
    Mail             = 236
    WWW              = 178
    InstantMessage   = 205
    Calculator       = 161
    LogOff           = 93
    Sleep            = 223
  # The alternate functions of the F1-F12 keys when F-Lock is off.
    Help             = 245
    Undo             = 135
    Redo             = 133
    New              = 131
    Open             = 191
    Close            = 175
    Reply            = 247
    Forward          = 132
    Send             = 170
    Spell            = 219
    Save             = 249
    Print            = 185
  [END KEYS]
[END MS-WNMK]

#### END Microsoft Keyboards ####


#### Micro Innovations Keyboards ####

[MI-KB6501]
  brandname = "Micro Innovations"
  modelname = "KB6501"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    Search           = 229
    Favorites        = 230
    WWW              = 178
    Mail             = 236
    MyComputer       = 235
    PowerOff         = 222
    Sleep            = 223
    Wake             = 227
    Calculator       = 161
    AudioMute        = 160
    AudioMedia       = 237
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioPrev        = 144
    AudioNext        = 153
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END MI-KB6501]

#### END Micro Innovations Keyboards ####


#### Mijuki Keyboards ####

[MCK-2000]
  brandname = "Mijuki"
  modelname = "MCK-2000 Multimedia Keyboard" 
  [KEYS]
    Mudo             = 160
    VolMenos         = 174
    VolMas           = 176
    Anterior         = 144
    Reproducir       = 162
    Siguiente        = 153
    Parar            = 164
    Calculadora      = 161
    Apagar           = 222
    Suspender        = 223
    Despertar        = 227
  [END KEYS]
[END MCK-2000]

#### END Mijuki Keyboards ####


#### Minowa Keyboards ####

[MINOWCK] #Tobias Schlottke
  brandname = "Minowa"
  modelname = "Cordless Keyboard"
  [KEYS]
    Calculator  = 161
    Home        = 178
    Mail        = 236
    Media       = 237
    Mute        = 160
    My Computer = 235
    Next        = 153
    Play|Pause  = 162
    Power       = 222
    Previous    = 144
    Stand By    = 223
    Stop        = 164
    VolumeUp    = 176
    VolumeDown  = 174
    Wake Up     = 227
  [END KEYS]
[END MINOWCK]

#### END Minowa Keyboards ####


#### Mitsubishi keyboards ####

[MITSUDT]
  brandname = "Mitsubishi"
  modelname = "Diamond Touch"
  [KEYS]
    Back        = 151
    Bookmarks   = 165
    Email       = 159
    Forward     = 148
    Mute        = 160
    Next        = 153
    Play|Pause  = 162
    S1          = 163
    Search      = 149
    Stop        = 152
    VolumeDown  = 176
    VolumeUp    = 174
    Previous    = 144
    WWW         = 178
  [END KEYS]
[END MITSUDT]

#### END Mitsubishi Keyboards ####


#### Mitsumi Keyboards ####

[MITSUHK] # Contributed by James Errico
  brandname = "Mistumi"
  modelname = "Hot Key"
  [KEYS]
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    WebRefresh  = 231
    Search      = 229
    Home        = 178
    Mail        = 236
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Play|Pause  = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
    Sleep       = 223
  [END KEYS]
[END MITSUHK]

#### END Mitsumi Keyboards ####


#### MS-Tech keyboards ####

[LT300]
  brandname = "MS-TECH"
  modelname = "LT-300 Design Multimedia Keyboard"
  [KEYS]
    Previous	= 144
    Stop        = 162
    Next        = 153
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Home        = 178
    Mail        = 236
    WebBack     = 234
    WebForward  = 233
    Sleep       = 223
  [END KEYS]
[END LT300]

#### END MS-Tech Keyboards ####


#### NEC Keyboards ####

[NEC-vM300]
  brandname = "NEC-Laptop"
  modelname = "Nec Versa M300"
  [KEYS]
    Internet    = 178
    Mail        = 236
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop        = 164
  [END KEYS]
[END NEC-vM300]

#### END NEC Keyboards ####


#### NEOLEC Keyboards ####

[NEO-WDST] # Contributed by Mathias Monse
  brandname = "NEOLEC"
  modelname = "Wireless Desktop ST"
  [KEYS]
    Mute        = 160
    VolumeDown  = 174
    VolumeUp    = 176
    Calculator  = 161
    Mail        = 236
    Home        = 178
    Play|Pause  = 162
    Media       = 237
    Stop        = 164
    Next        = 153
    Previous    = 144
    My Desktop  = 235
    Favorites   = 230
    Sleep       = 223
    WebBack     = 234
    WebForward  = 233
    WebRefresh  = 231
    WebStop     = 232
    WebSearch   = 229
  [END KEYS]
[END NEO-WDST]

#### END NEOLEC Keyboards ####


#### Oretec Keyboards ####

[MCK-800]
  brandname = "Oretec"
  modelname = "MCK-800 MM/Internet keyboard"
  [KEYS]
    Internet    = 161
    Mute        = 158
    VolumeDown  = 232
    VolumeUp    = 176
    ScrollDown  = 152
    ScrollUp    = 144
    Previous    = 151
    Play        = 146
    Next        = 174
    Stop        = 163
    Zoom Out    = 153
    Zoom In     = 178
    Calculator  = 164
    Xfer        = 165
    Menu        = 162
    Mail        = 166
    Power       = 222
    Suspend     = 223
    Wake        = 227
  [END KEYS]
[END MCK-800]

#### END Oretec Keyboards ####


#### Prismabook Keyboards ####

[PBN750]
  brandname = "Prismabook"
  modelname = "N750 / Mitac 8080 Laptop Keyboard"
  [KEYS]
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
  [END KEYS]
[END PBN750]

#### END Prismabook Keyboards ####


#### Propeller Keyboards ####

[KTEZ-1000]
  brandname = "Propeller"
  modelname = "Voyager (KTEZ-1000)"
  [KEYS]
    Calculator  = 165
    Xfer        = 152
    Dos         = 232
    My Documents = 161
    Internet    = 178
    Menu        = 166 
    Game        = 163
    Play|Pause  = 162
    Rewind      = 146
    Previous    = 144
    Next        = 153
    Stop        = 164
    Close       = 151
    Record      = 158
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
    Sleep       = 250 
  [END KEYS]
[END KTEZ-1000]

#### END Propeller Keyboards ####


#### QTronix keyboards ####

[SCORPIUSKI]
  brandname = "QTronix"
  modelname = "Advance Scorpius KI"
  [KEYS]
    Previous    = 144
    Play        = 162
    Stop        = 164
    Next        = 153
    Media       = 237
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
    Wake        = 227
    Sleep       = 223
    Power       = 222
    Calculator  = 161
    My Computer = 235
    Mail        = 236
    Favorites   = 230
    Home        = 178
    WebBack     = 234
    WebForward  = 233
    WebStop     = 232
    WebReload   = 231
    Search      = 229
  [END KEYS]
[END SCORPIUSKI]

[QTSC98N+]
  brandname = "QTronix"
  modelname = "Scorpius 98N+ & 990P"
  [KEYS]
    Previous    = 161
    Play        = 162
    Stop        = 164
    Next        = 163
    Record      = 176
    VolumeDown  = 174
    Mute        = 166
    VolumeUp    = 160
    Wake        = 147
    Sleep       = 152
    Power       = 177
    Calculator  = 232
    WebReload   = 159
    Home        = 165
    WebBack     = 158
    Search      = 151
    WebStop     = 178
    WebForward  = 146
    ScrollUp    = 153
    ScrollDown  = 144
  [END KEYS]
[END QTSC98N+]

[QTSC98NHP] # By Andreas Steinel
  brandname = "QTronix"
  modelname = "Scorpius 98NH Plus"
  [KEYS]
    Arrow       = 121
    Calculator  = 161
    Coffe-Key   = 146
    Filemanager = 223
    History     = 232
    WebBack     = 234
    WebForward  = 233
    Mute        = 166
    Play|Pause  = 159
    Search      = 229
    VolumeDown  = 158
    VolumeUp    = 165
    Web         = 178
  [END KEYS]
[END QTSC98NHP]

[QTSCSK2]
  brandname = "QTronix"
  modelname = "Scorpius SKII (2 ACPI keys)"
  [KEYS]
    Sleep       = 223
    Standby     = 222
  [END KEYS]
[END QTSCSK2]

[QTSCSK2P]
  brandname = "QTronix"
  modelname = "Scorpius SKIIP (3 ACPI keys)"
  [KEYS]
    Resume      = 227
    Sleep       = 223
    Standby     = 222
  [END KEYS]
[END QTSCSK2P]

#### END Qtronix Keyboards ####


#### RealDigital Keyboards ####

# Contributed by Guillaume Bailey gvb013000<->utdallas.edu
# FCC ID = HQX-AKMC35 Looks identical to Creative's Desktop Wireless 8000
# except for scrollwheel on the Creative model Word/Excel buttons don't 
# create scancodes in showkey -s linux problem?
[RD-AKMx-Cx]
brandname = "RealDigital"
modelname = "AKM96/C35\AKM93/C35 (Incomplete)"
[KEYS]
#   Word             = ?
#   Excel            = ?
    Search           = 229
    Favorites        = 230
    Previous         = 234
    Forward          = 233
    Stop             = 232
    Refresh          = 231
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioNext        = 153
    AudioPrev        = 144
    AudioMute        = 160
    Mail             = 236
    Home             = 178
    Calculator       = 161
    PowerOff         = 222
    Sleep            = 223
  [END KEYS]
[END RD-AKMx-Cx]

#### END RealDigital Keyboards ####


#### SafeWay Keyboards ####

[SW20P] # Contributed by Rodrigo Araujo
  brandname = "SafeWay"
  modelname = "SW-20-P"
  [KEYS]
    Back        = 234
    Calculator  = 161
    Favorites   = 230
    Forward     = 233
    Mail        = 236
    Media       = 237
    MediaStop   = 164
    Mute        = 160
    My Computer = 235
    Next        = 153
    Play|Pause  = 162
    Power       = 222
    Previous    = 144
    Refresh     = 231
    Search      = 229
    Sleep       = 223
    Stop        = 232
    VolumeDown  = 174
    VolumeUp    = 176
    Wake        = 227
    Web|Home    = 178
  [END KEYS]
[END SW20P]

#### END SafeWay Keyboards ####

#### Samsung Keyboards ####

[SS4500]
  brandname = "Samsung"
  modelname = "Samsung SDM 4500P"
  [KEYS]
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Eject       = 152
    Play|Pause  = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
    Internet    = 178
    Mail        = 236
    Sleep       = 223
    Help        = 166
    Explorer    = 217
    Close       = 137
    Bookmark    = 138
    UserDefined1 = 130
    UserDefined2 = 131
    UserDefined3 = 132
    UserDefined4 = 133
    UserDefined5 = 134
  [END KEYS]
[END SS4500]

#### END Samsung Keyboards ####


#### Sharp Keyboards ####

[SHARP-MM20]
  brandname               = "Sharp"
  modelname               = "MM20 Laptop Keyboard"
  [KEYS]
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Sleep            = 223
  [END KEYS]
[END SHARP-MM20]

#### END Sharp Keyboards ####


#### Silitek Keyboards ####

[SK720H]
  brandname = "Silitek"
  modelname = "SK-720H"
  [KEYS]
    Eject       =  152 
    Internet    =  178
    Previous    =  144
    Play        =  162
    Stop        =  164
    Next        =  153
    VolumeDown  =  174
    VolumeUp    =  176
    Mute        =  160
    Help        =  166 
    Dos         =  161
    Cut         =  163
    Wake        =  227
    Power       =  222
    Sleep       =  223
  [END KEYS]
[END SK720H]

[SK1300]
  brandname = "Silitek"
  modelname = "SK-1300 (and clones)"
  [KEYS]
    Internet    = 160
    WebBack     = 166
    WebForward  = 158
    WebStop     = 178
    Sleep       = 165
    Previous    = 144
    Next        = 153
    Play        = 162
    Stop        = 164
    Eject       = 146
    VolumeUp    = 176
    VolumeDown  = 174
  [END KEYS]
[END SK1300]

[SK2500]
  brandname = "Silitek"
  modelname = "SK-2500 (and clones)"
  [KEYS]
    Power       = 165
    Screensaver = 250
    Internet    = 178
    Calculator  = 161
    Xfer        = 163
    Close       = 151
    Previous    = 144
    Play        = 162
    Stop        = 164
    Next        = 153
    Record      = 158
    Rewind      = 146
    Menu        = 166
    Eject       = 152
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
    Next        = 153
    Eject       = 152
  [END KEYS]
[END SK2500]

[SK6200]
  brandname = "Silitek"
  modelname = "SK-6200 (and clones)"
  [KEYS]
    Stop        = 164
    Play        = 162
    Previous    = 163
    Next        = 161
    VolumeUp    = 150
    VolumeDown  = 148
    Mute        = 160
    Power       = 222
    Sleep       = 223
    Internet    = 158
    Favorites   = 146
    Mail        = 178
    WebBack     = 151
    WebForward  = 153
  [END KEYS]
[END SK6200]

[SK7100]
  brandname = "Silitek"
  modelname = "SK-7100"
  [KEYS]
    Close       = 151
    CD          =  165
    Video       =  152
    Internet    =  178
    Up          =  158
    Previous    =  144
    Pause       =  146
    Play        =  162
    Stop        =  164
    Next        =  153
    VolumeDown  =  174
    VolumeUp    =  176
    Mute        =  160
    Display     =  166
  [END KEYS]
[END SK7100]

#### END Silitek Keyboards ####


#### SVEN Keyboards ####

[SVEN2500]
  brandname = "SVEN"
  modelname = "ErGonomic 2500"
  [KEYS]
    WebBack     = 232
    WebForward  = 146
    WebStop     = 163
    WebReload   = 169
    Search      = 174
    Favorites   = 176
    Home        = 158
    Previous    = 153
    Stop        = 154
    Play        = 144
    Next        = 226
    Mute        = 166
    VolumeDown  = 165
    VolumeUp    = 151
    Zoom Out    = 152
    Zoom In     = 161
    ScrollDown  = 178
    ScrollUp    = 177
    Mail        = 160
    My Computer = 162
    Calculator  = 168
    Screensaver = 164
    Power       = 222
    Sleep       = 223
    Wake        = 227
  [END KEYS]
[END SVEN2500]

[SVEN650]
  brandname = "SVEN"
  modelname = "Internet 650"
  [KEYS]
    AudioPrev        = 144
    AudioStop        = 164
    AudioPlay|Pause  = 162
    AudioNext        = 153
    AudioMute        = 160
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Calculator       = 161
    PowerOff         = 222
    Sleep            = 223
    Wake             = 227
  [END KEYS]
[END SVEN650]

#### END SVEN Keyboards ####


#### Sweex Keyboards ####

[SWX-TM]
  brandname = "Sweex"
  modelname = "Turbo-Media Keyboard"
  [KEYS]
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    Back             = 234
    Calculator       = 161
    Favorites        = 230
    Forward          = 233
    WWW              = 178
    Mail             = 236
    AudioMedia       = 237
    AudioMute        = 160
    MyComputer       = 235
    AudioNext        = 153
    AudioPlay|Pause  = 162
    PowerOff         = 222
    AudioPrev        = 144
    Refresh          = 231
    Search           = 229
    Sleep            = 223
    AudioStop        = 232
    Wake             = 227
  [END KEYS]
[END SWX-TM]

### END Sweex Keyboards ####


#### Symplon Keyboards ####

[SPPB]
  brandname = "Symplon"
  modelname = "PaceBook (Tablet PC)"
  [KEYS]
    RotationPB  = 97
    MenuPB      = 98
    UserPB      = 110
    RotationKB  = 165
    MenuKB      = 166
    Splitscreen = 147
    User1KB     = 235
    User2KB     = 161
    Sleep       = 223
    New         = 151
    Mail        = 236
    Internet    = 178
    Support     = 148
  [END KEYS]
[END SPPB]

#### END Symplon Keyboards ####


#### Tevion Keyboards ####

[TV-MD40273]
  brandname = "Tevion"
  modelname = "MD40273"
  [KEYS]
    Calculator       = 161
    CdPlayer         = 237
    WWW              = 178
    Mail             = 236
    MyComputer       = 235
    NewFolder        = 230
    Sleep            = 223
    AudioPrev        = 144
    AudioNext        = 153
    AudioMute        = 160
    AudioPlay|Pause  = 162
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Back             = 234
    Forward          = 233
    Reload           = 231
    Search           = 229
    Stop             = 232
  [END KEYS]
[END TV-MD40273]

#### Tevion Keyboards ####


#### 'The Best Choice' Keyboards ####

[TBC-MKHK820]
  brandname = "The Best Choice"
  modelname = "Multimedia Keyboard HK-820"
  [KEYS]
    Email       = 121
    Search      = 229
    Explorer    = 230
    Home        = 130
    Play|Pause  = 236
    Stop        = 159
    VolumeDown  = 151
    VolumeUp    = 165
    Mute        = 158
    TV          = 166
    Power       = 222
    Sleep       = 223
    WakeUp      = 227
  [END KEYS]
[END TBCM-KHK820]

#### END 'The Best Choice' Keyboards ####


#### Toshiba Keyboards ####

[TOSHIBA2430]
  brandname = "Toshiba"
  modelname = "2430 notebook keyboard"
  [KEYS]
    Mute        = 160
    Lock        = 238
    Sleep       = 151
    Suspend     = 152
    BrightnessLower = 239
    BrightnessHigher = 217
    RadioNetwork = 150
    RadioNetworkRelease = 248
    TouchpadOn  = 158
    TouchpadOff = 159
    Internet    = 178
    Toshiba     = 236
    ModeCD      = 237
    ModeMediaPlayer = 147
    ModeOff     = 180
    Previous    = 144
    Next        = 153
    Play|Pause  = 162
    Stop        = 164
  [END KEYS]
[END TOSHIBA2430]

#### END Thosiba Keyboards ####


### Trust Keyboards ####

[T2KWOM] # Vytvoril Soban Petr
  brandname = "Trust"
  modelname = "280KS/270KD Keyboard Wireless Optical Mouse"
  [KEYS]
    Back        = 234
    Forward     = 233
    Stop        = 232
    Refresh     = 231
    Search      = 229
    Favorites   = 230
    WebHome     = 178
    Mail        = 236
    MMForward   = 153
    MMPlay      = 162
    MMRewind    = 144
    MMStop      = 164
    VolumeDown  = 174
    VolumeUp    = 176
    Mute        = 160
    Media       = 237
    MyComputer  = 235
    Calculator  = 161
    Sleep       = 223
  [END KEYS]
[END T2KWOM]

[T3ESWD] # Contributed by Martin Rademacher
  brandname = "Trust"
  modelname = "370B Easy Scroll Wireless Deskset"
  [KEYS]
    WebBack     = 234
    Browser     = 229
    WebForward  = 233
    Home        = 178
    Next        = 153
    Play|Pause  = 162
    Previous    = 144
    Stop        = 164
    Mail        = 236
    NewFolder   = 230
    OBack       = 234
    OForward    = 233
    Power       = 222
    Reload      = 231
    ScrollDown  = 139
    ScrollUp    = 139
    Sleep       = 223
    Stop        = 232
    VolumeDown  = 174
    Mute        = 160
    VolumeUp    = 176
  [END KEYS]
[END T3ESWD]

[TDAK]
  brandname = "Trust"
  modelname = "Direct Access Keyboard"
  [KEYS]
    Calc        = 161
    Close       = 151
    Eject       = 152
    Menu        = 166
    Mute        = 160
    Next        = 153
    Play        = 162
    Prev        = 144
    Record      = 158
    Rew         = 146
    ScreenSaver = 250
    Stop        = 164
    Suspend     = 165
    VolumeDown  = 174
    VolumeUp    = 176
    WWW         = 178
    XFer        = 163
  [END KEYS]
[END TDAK]

[TEZS] # by Nico Troost
  brandname = "Trust"
  modelname = "Easy Scroll Silverline Keyboard"
  [KEYS]
    Back             = 234
    Forward          = 233
    Stop             = 232
    WWW              = 178
    Mail             = 236
    Favorites        = 230
    Refresh          = 231
    Search           = 229
    AudioStop        = 164
    AudioPlay|Pause  = 162
    AudioLowerVolume = 174
    AudioMute        = 160
    AudioRaiseVolume = 176
    AudioPrev        = 144
    AudioNext        = 153
    PowerOff         = 222
    Sleep            = 223

#    Scroll-Up/Down/Press doesnt give a keycode
#    Switch app  = Alt+Shift+Tab
#    Close app   = Alt+F4
#    Mark        = Shift press
#    Cut         = Ctrl+x
#    Copy        = Ctrl+c
#    Paste       = Ctrl+v
#    Word        = Ctrl+Alt+d
#    Excel       = Ctrl+Alt+e
#    PPoint      = Ctrl+Alt+p
#    Calendar    = Ctrl+Alt+o
#    Calculator  = Ctrl+Alt+c
#  With Office lock key
#    Help        = F1
#    New         = Ctrl+n
#    Open        = Ctrl+o
#    Save        = Ctrl+s
#    Replace     = Ctrl+h
#    Spell       = F7
#    Undo        = Ctrl+z
#    Redo        = Ctrl+y
#    Reply       = Ctrl+r
#    Reply All   = Ctrl+Shift+r
#    Forward     = Ctrl+f
#    Send        = Alt+s
#    Print       = Ctrl+p
  [END KEYS]
[END TEZS] 

[TPPK]
  brandname = "Trust"
  modelname = "Power Plus Keyboard"
  [KEYS]
    PowerOff = 222
    Sleep    = 223
    Wake     = 227
  [END KEYS]
[END TPPK]

[T270-KD]
  brandname = "Trust"
  modelname = "270-KD Silverline Keyboard"
  [KEYS]
    Calculator       = 161
    Favorites        = 230
    Mail             = 236
    AudioMedia       = 237
    AudioMute        = 160
    MyComputer       = 235
    AudioNext        = 153
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    Search           = 229
    Sleep            = 223
    AudioStop        = 164
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    WWW              = 178
    Back             = 234
    Forward          = 233
    Refresh          = 231
    Stop             = 232
  [END KEYS]
[END T270-KD]

[TWK3] # Contributed by ChriStoph Federer
  brandname = "Trust"
  modelname = "Wireless Keyboard 300KD"
  [KEYS]
    Previous    = 144
    Next        = 153
    Stop        = 164
    Mail        = 236
    Home        = 178
    Mixer       = 160
    Play|Pause  = 162
    VolumeDown  = 174
    VolumeUp    = 176
    Go          = 230
    Sleep       = 223
    Zoom        = 229
  [END KEYS]
[END TWK3]

[TWC]
  brandname = "Trust"
  modelname = "Wireless Keyboard Classic"
  [KEYS]
    Internet    = 178
    WebBack     = 234
    WebForward  = 233
    Mail        = 236
    Calculator  = 161
    VolumeUp    = 176
    Mute        = 160
    VolumeDown  = 174
    Previous    = 144
    Next        = 153
    Play|Pause  = 162
    Stop        = 164
    Eject       = 158
    Sleep       = 223
    Wake        = 227
    Screensaver = 145
  [END KEYS]
[END TWC]

#### END Trust Keyboards ####


#### Tsunami Keyboards ####

[TSU-SK2000]
  brandname = "Tsunami"
  modelname = "SK2000 Keyboard"
  [KEYS]
    Back             = 234
    Calculator       = 161
    Favorites        = 230
    Forward          = 233
    Mail             = 236
    AudioMedia       = 237
    AudioMute        = 160
    MyComputer       = 235
    AudioNext        = 153
    AudioPlay|Pause  = 162
    PowerOff         = 222
    AudioPrev        = 144
    Refresh          = 231
    Search           = 229
    Sleep            = 223
    AudioStop        = 232
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Wake             = 227
    WWW              = 178
  [END KEYS]
[END TSU-SK2000]

#### END Tsunami Keyboards ####


### Typhoon Keyboards ####

[TYPHONN] # By Roi Pin Trigo
  brandname = "Typhoon"
  modelname = "Navigator"
  [KEYS]
    WebBack     = 234
    Calculator  = 161
    Email       = 236
    Favorites   = 230
    WebForward  = 233
    My Computer = 235
    Refresh     = 231
    Search      = 229
    WebStop     = 232
    Web|Home    = 178
    Previous    = 144
    Next        = 153
    Stop        = 164
    Mute        = 160
    Play|Pause  = 162
    VolumeDown  = 174
    VolumeUp    = 176
  [END KEYS]
[END TYPHONN]

[TYP-NOXP]
  brandname = "Typhoon"
  modelname = "Navigator Office XP"
  [KEYS]
    WWW              = 178
    Mail             = 236
    Favorite         = 230
    AudioMute        = 160
    AudioNext        = 153
    AudioPlay|Pause  = 162
    PowerOff         = 222
    AudioPrev        = 144
    Refresh          = 231
    Search           = 229
    Sleep            = 223
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Back             = 234
    Forward          = 233
    Stop             = 232
  [END KEYS]
[END TYP-NOXP]

[TYP-WMKB]
  brandname = "Typhoon"
  modelname = "Wireless Multimedia Keyboard"
  [KEYS]
    WWW              = 178
    Mail             = 236
    Favorite         = 230
    AudioMute        = 160
    AudioNext        = 153
    AudioPrev        = 144
    AudioPlay|Pause  = 162
    Refresh          = 231
    Search           = 229
    Sleep            = 223
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    AudioMedia       = 237
    Stop             = 232
    Back             = 234
    Forward          = 233
    Calculator       = 161
    MyComputer       = 235
 [END KEYS]
[END TYP-WMKB]

#### END Typhoon Keyboards ####


#### Turbo Media Keyboards ####

[TURBOTK9801R]
  brandname = "Turbo-Media"
  modelname = "KB-9801R+"
  [KEYS]
    Eject       = 241
    Next        = 233
    Play|Pause  = 194
    Previous    = 217
    Stop        = 228
    Calculator  = 238
    Close       = 195
    Copy        = 254
    Cut         = 253
    Terminal    = 196
    Game        = 249
    Menu        = 234
    My Documents = 176
    Paste       = 255
    Recorder Stop = 169
    Recorder Rewind|Recorder Play = 121
    Rotate      = 160
    Sleep       = 163
    VolumeDown  = 218
    Mute        = 216
    VolumeUp    = 240
    WWW         = 247
    XFer        = 119
  [END KEYS]
[END TURBOTK9801R]

#### END Turbo Media Keyboards ####


#### UMAX Keyboards ####

[UMAXOK] # Contributed by Josef Hajas
  brandname = "Umax"
  modelname = "Office Keyboard"
  [KEYS]
    Back        = 234
    Forward     = 233
    BlueLeft    = 166
    BlueRight   = 168
    BlueUp|BlueDown = 139
    Stop        = 232
    WWW         = 178
    Email       = 236
    Favorites   = 230
    Refresh     = 231
    Search      = 229
    PowerOff    = 222
    Sleep       = 223
    Mute        = 160
    VolumeUp    = 176
    VolumeDown  = 174
    Play|Pause  = 162
    Stop        = 164
    Previous    = 144
    Next        = 153
#   APP         = xxx Alt+Shift+TAB
#   Close       = xxx Alt+F4
#   Mark        = xxx Shift (switch - on/off)
#   Cut         = xxx Shift+Del
#   Paste       = xxx Ctrl+v
#   Copy        = xxx Ctrl+c
#   Word        = xxx Ctrl+Alt+d
#   Excel       = xxx Ctrl+Alt+e 
#   PPoint      = xxx Ctrl+Alt+p
#   Calendar    = xxx Ctrl+Alt+o 
#   Calc        = xxx Ctrl+Alt+c
#   MyCom       = xxx Meta+e 
#   LogOff      = xxx Meta Meta Up Up Up Return
# With F function    
#   Help        = xxx F1
#   New         = xxx Ctrl+n
#   Open        = xxx Ctrl+o
#   Save        = xxx F12
#   Replace     = xxx F5
#   Spell       = xxx F7
#   Undo        = xxx Alt+BackSpace
#   Redo        = xxx Alt+Return
#   Reply       = xxx Ctrl+r
#   Forward     = xxx Ctrl+f
#   Send        = xxx Ctrl+Return
#   Print       = xxx Shift+F12
  [END KEYS]
[END UMAXOK]

#### END UMAX Keyboards ####


#### Unitek Keyboards ####

[UNI3616] # Contributed by Balthazar of Damones
  brandname = "Unitek"
  modelname = "Internet & Multimedia Keyboard KB-3616 (9 keys)"
  [KEYS]
    Mute        = 160
    Media       = 237
    Email       = 236
    Home        = 178
    Power       = 222
    Sleep       = 223
    Wake        = 227
    MyComputer  = 235
    Calculator  = 161
  [END KEYS]
[END UNI3616]

#### END Unitek Keyboards ####


#### Viewsonic Keyboards ####

[VS-KU201]
  brandname = "ViewSonic"
  modelname = "KBM-KU-201"
  [KEYS]
    WWW              = 130
    Mail             = 236
    AudioPrev        = 234
    AudioNext        = 233
    Search           = 229
    Refresh          = 121
    MyComputer       = 230
    AudioStop        = 232
    AudioMute        = 166
    AudioLowerVolume = 165
    AudioRaiseVolume = 158
    Stop             = 151
    Back             = 164
    AudioPlay|Pause  = 159
    Forward          = 162
  [END KEYS]
[END VS-KU201]

#### END Viewsonic Keyboards ####


#### Vivanco Keyboards ####

[VIV-ProLight]
  brandname = "Vivanco"
  modelname = "Pro Light Keyboard"
  [KEYS]
    Favorites        = 230
    WWW              = 178
    Mail             = 236
    AudioMedia       = 237
    AudioMute        = 160
    Refresh          = 231
    Search           = 229
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Back             = 234
    Forward          = 233
    Logoff           = 222
    AudioNext        = 153
    AudioPlay|Pause  = 162
  [END KEYS]
[END VIV-ProLight]

[VIV-SNW]
  brandname = "Vivanco"
  modelname = "Snowboard USB"
  [KEYS]
    AudioMute        = 160
    AudioRaiseVolume = 176
    AudioLowerVolume = 174
    Sleep            = 223
  [END KEYS]
[END VIV-SNW]

#### END Vivanco Keyboards ####


#### Yahoo Keyboards ####

[YAHOO]
  brandname = "Yahoo"
  modelname = "Yahoo! Internet Keyboard (16 keys)"
  [KEYS]
    Previous    = 145
    Play        = 146
    Stop        = 158
    Next        = 159
    Record      = 160
    VolumeDown  = 161
    VolumeUp    = 162
    Mute        = 163
    Close       = 164
    Calculator  = 165
    Help        = 166
    Mail        = 167
    Internet    = 168
    Power       = 222
    Sleep       = 223
    Wake        = 227
  [END KEYS]
[END YAHOO]

#### END Yahoo Keyboards ####


#### Zippy Keyboards ####

[ZIP-WK711] # Alex Thomsen Leth (Denmark)
  brandname = "Zippy"
  modelname = "wk-711"
  [KEYS]
    Play|Pause  = 159
    Previous    = 164
    Next        = 162
    Stop        = 151
    VolumeUp    = 158
    VolumeDown  = 165
    Mute        = 166
    Home        = 130
    Mail        = 236
    WebBack     = 234
    WebForward  = 233
    WebRefresh  = 121
    WebStop     = 232
    Search      = 229
    Favorites   = 230
    Wake        = 112
    Sleep       = 227
    Power       = 222
  [END KEYS]
[END ZIP-WK711]

[ZIP-WK712]
  brandname = "Zippy"
  modelname = "WK-712"
  [KEYS]
    Back             = 234
    Bookmarks        = 230
    AudioNext        = 153
    Forward          = 233
    WWW              = 178
    Mail             = 236
    AudioMute        = 160
    AudioPlay|Pause  = 162
    Power            = 222
    Reload           = 231
    AudioPrev        = 144
    Search           = 229
    Sleep            = 223
    AudioStop        = 164
    AudioLowerVolume = 174
    AudioRaiseVolume = 176
    Wake             = 227
  [END KEYS]
[END ZIP-WK712]

#### END Zippy Keyboards ####


#### X-Tensions Keyboards ####

[XT-XK240]
  brandname = "X-Tensions"
  modelname = "XK-240"
  [KEYS]
    Back             = 234
    Calculator       = 161
    Cancel           = 232
    AudioLowerVolume = 176
    Desktop          = 198
    Forward          = 233
    Homepage         = 230
    AudioRaiseVolume = 174
    WWW              = 130
    Mail             = 236
    AudioMute        = 160
    AudioNext        = 153
    Open             = 129
    AudioPlay|Pause  = 162
    AudioPrev        = 144
    Search           = 122
    AudioStop        = 164
    Update           = 231
  [END KEYS]
[END XT-XK240]

#### END X-Tensions Keyboards ####
